@@ -149,16 +149,16 @@ pub struct ILockScreenUnlockingEventArgs_Vtbl {
     #[cfg(not(feature = "Foundation"))]
     Deadline: usize,
 }
-#[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+#[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
 #[repr(transparent)]
 pub struct LockApplicationHost(::windows::core::IUnknown);
 impl LockApplicationHost {
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
     pub fn RequestUnlock(&self) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RequestUnlock)(::core::mem::transmute_copy(this)).ok() }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Unlocking<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::TypedEventHandler<LockApplicationHost, LockScreenUnlockingEventArgs>>>(&self, handler: Param0) -> ::windows::core::Result<super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -167,13 +167,13 @@ impl LockApplicationHost {
             (::windows::core::Interface::vtable(this).Unlocking)(::core::mem::transmute_copy(this), handler.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveUnlocking<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveUnlocking)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
     pub fn GetForCurrentView() -> ::windows::core::Result<LockApplicationHost> {
         Self::ILockApplicationHostStatics(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
@@ -204,10 +204,6 @@ impl ::core::fmt::Debug for LockApplicationHost {
 }
 unsafe impl ::windows::core::RuntimeType for LockApplicationHost {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.ApplicationModel.LockScreen.LockApplicationHost;{38ee31ad-d94f-4e7c-81fa-4f4436506281})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for LockApplicationHost {
     type Vtable = ILockApplicationHost_Vtbl;
@@ -231,7 +227,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for LockAppli
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a LockApplicationHost {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &LockApplicationHost {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -251,18 +247,18 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for LockA
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a LockApplicationHost {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &LockApplicationHost {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for LockApplicationHost {}
 unsafe impl ::core::marker::Sync for LockApplicationHost {}
-#[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+#[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
 #[repr(transparent)]
 pub struct LockScreenBadge(::windows::core::IUnknown);
 impl LockScreenBadge {
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Storage_Streams\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Storage_Streams'*"]
     #[cfg(feature = "Storage_Streams")]
     pub fn Logo(&self) -> ::windows::core::Result<super::super::Storage::Streams::IRandomAccessStream> {
         let this = self;
@@ -271,7 +267,7 @@ impl LockScreenBadge {
             (::windows::core::Interface::vtable(this).Logo)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Storage::Streams::IRandomAccessStream>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Storage_Streams\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Storage_Streams'*"]
     #[cfg(feature = "Storage_Streams")]
     pub fn Glyph(&self) -> ::windows::core::Result<super::super::Storage::Streams::IRandomAccessStream> {
         let this = self;
@@ -280,7 +276,7 @@ impl LockScreenBadge {
             (::windows::core::Interface::vtable(this).Glyph)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Storage::Streams::IRandomAccessStream>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Number(&self) -> ::windows::core::Result<super::super::Foundation::IReference<u32>> {
         let this = self;
@@ -289,7 +285,7 @@ impl LockScreenBadge {
             (::windows::core::Interface::vtable(this).Number)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::IReference<u32>>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
     pub fn AutomationName(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -297,7 +293,7 @@ impl LockScreenBadge {
             (::windows::core::Interface::vtable(this).AutomationName)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
     pub fn LaunchApp(&self) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).LaunchApp)(::core::mem::transmute_copy(this)).ok() }
@@ -321,10 +317,6 @@ impl ::core::fmt::Debug for LockScreenBadge {
 }
 unsafe impl ::windows::core::RuntimeType for LockScreenBadge {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.ApplicationModel.LockScreen.LockScreenBadge;{e95105d9-2bff-4db0-9b4f-3824778b9c9a})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for LockScreenBadge {
     type Vtable = ILockScreenBadge_Vtbl;
@@ -348,7 +340,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for LockScree
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a LockScreenBadge {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &LockScreenBadge {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -368,18 +360,18 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for LockS
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a LockScreenBadge {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &LockScreenBadge {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for LockScreenBadge {}
 unsafe impl ::core::marker::Sync for LockScreenBadge {}
-#[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+#[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
 #[repr(transparent)]
 pub struct LockScreenInfo(::windows::core::IUnknown);
 impl LockScreenInfo {
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn LockScreenImageChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::TypedEventHandler<LockScreenInfo, ::windows::core::IInspectable>>>(&self, handler: Param0) -> ::windows::core::Result<super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -388,13 +380,13 @@ impl LockScreenInfo {
             (::windows::core::Interface::vtable(this).LockScreenImageChanged)(::core::mem::transmute_copy(this), handler.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveLockScreenImageChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveLockScreenImageChanged)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Storage_Streams\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Storage_Streams'*"]
     #[cfg(feature = "Storage_Streams")]
     pub fn LockScreenImage(&self) -> ::windows::core::Result<super::super::Storage::Streams::IRandomAccessStream> {
         let this = self;
@@ -403,7 +395,7 @@ impl LockScreenInfo {
             (::windows::core::Interface::vtable(this).LockScreenImage)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Storage::Streams::IRandomAccessStream>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn BadgesChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::TypedEventHandler<LockScreenInfo, ::windows::core::IInspectable>>>(&self, handler: Param0) -> ::windows::core::Result<super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -412,13 +404,13 @@ impl LockScreenInfo {
             (::windows::core::Interface::vtable(this).BadgesChanged)(::core::mem::transmute_copy(this), handler.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveBadgesChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveBadgesChanged)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn Badges(&self) -> ::windows::core::Result<super::super::Foundation::Collections::IVectorView<LockScreenBadge>> {
         let this = self;
@@ -427,7 +419,7 @@ impl LockScreenInfo {
             (::windows::core::Interface::vtable(this).Badges)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::Collections::IVectorView<LockScreenBadge>>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn DetailTextChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::TypedEventHandler<LockScreenInfo, ::windows::core::IInspectable>>>(&self, handler: Param0) -> ::windows::core::Result<super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -436,13 +428,13 @@ impl LockScreenInfo {
             (::windows::core::Interface::vtable(this).DetailTextChanged)(::core::mem::transmute_copy(this), handler.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveDetailTextChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveDetailTextChanged)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn DetailText(&self) -> ::windows::core::Result<super::super::Foundation::Collections::IVectorView<::windows::core::HSTRING>> {
         let this = self;
@@ -451,7 +443,7 @@ impl LockScreenInfo {
             (::windows::core::Interface::vtable(this).DetailText)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::Collections::IVectorView<::windows::core::HSTRING>>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn AlarmIconChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::TypedEventHandler<LockScreenInfo, ::windows::core::IInspectable>>>(&self, handler: Param0) -> ::windows::core::Result<super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -460,13 +452,13 @@ impl LockScreenInfo {
             (::windows::core::Interface::vtable(this).AlarmIconChanged)(::core::mem::transmute_copy(this), handler.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveAlarmIconChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveAlarmIconChanged)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Storage_Streams\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Storage_Streams'*"]
     #[cfg(feature = "Storage_Streams")]
     pub fn AlarmIcon(&self) -> ::windows::core::Result<super::super::Storage::Streams::IRandomAccessStream> {
         let this = self;
@@ -494,10 +486,6 @@ impl ::core::fmt::Debug for LockScreenInfo {
 }
 unsafe impl ::windows::core::RuntimeType for LockScreenInfo {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.ApplicationModel.LockScreen.LockScreenInfo;{f59aa65c-9711-4dc9-a630-95b6cb8cdad0})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for LockScreenInfo {
     type Vtable = ILockScreenInfo_Vtbl;
@@ -521,7 +509,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for LockScree
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a LockScreenInfo {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &LockScreenInfo {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -541,18 +529,18 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for LockS
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a LockScreenInfo {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &LockScreenInfo {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for LockScreenInfo {}
 unsafe impl ::core::marker::Sync for LockScreenInfo {}
-#[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+#[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
 #[repr(transparent)]
 pub struct LockScreenUnlockingDeferral(::windows::core::IUnknown);
 impl LockScreenUnlockingDeferral {
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
     pub fn Complete(&self) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).Complete)(::core::mem::transmute_copy(this)).ok() }
@@ -576,10 +564,6 @@ impl ::core::fmt::Debug for LockScreenUnlockingDeferral {
 }
 unsafe impl ::windows::core::RuntimeType for LockScreenUnlockingDeferral {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.ApplicationModel.LockScreen.LockScreenUnlockingDeferral;{7e7d1ad6-5203-43e7-9bd6-7c3947d1e3fe})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for LockScreenUnlockingDeferral {
     type Vtable = ILockScreenUnlockingDeferral_Vtbl;
@@ -603,7 +587,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for LockScree
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a LockScreenUnlockingDeferral {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &LockScreenUnlockingDeferral {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -623,18 +607,18 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for LockS
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a LockScreenUnlockingDeferral {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &LockScreenUnlockingDeferral {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for LockScreenUnlockingDeferral {}
 unsafe impl ::core::marker::Sync for LockScreenUnlockingDeferral {}
-#[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+#[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
 #[repr(transparent)]
 pub struct LockScreenUnlockingEventArgs(::windows::core::IUnknown);
 impl LockScreenUnlockingEventArgs {
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen'*"]
     pub fn GetDeferral(&self) -> ::windows::core::Result<LockScreenUnlockingDeferral> {
         let this = self;
         unsafe {
@@ -642,7 +626,7 @@ impl LockScreenUnlockingEventArgs {
             (::windows::core::Interface::vtable(this).GetDeferral)(::core::mem::transmute_copy(this), &mut result__).from_abi::<LockScreenUnlockingDeferral>(result__)
         }
     }
-    #[doc = "*Required features: `\"ApplicationModel_LockScreen\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'ApplicationModel_LockScreen', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Deadline(&self) -> ::windows::core::Result<super::super::Foundation::DateTime> {
         let this = self;
@@ -670,10 +654,6 @@ impl ::core::fmt::Debug for LockScreenUnlockingEventArgs {
 }
 unsafe impl ::windows::core::RuntimeType for LockScreenUnlockingEventArgs {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.ApplicationModel.LockScreen.LockScreenUnlockingEventArgs;{44e6c007-75fb-4abb-9f8b-824748900c71})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for LockScreenUnlockingEventArgs {
     type Vtable = ILockScreenUnlockingEventArgs_Vtbl;
@@ -697,7 +677,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for LockScree
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a LockScreenUnlockingEventArgs {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &LockScreenUnlockingEventArgs {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -717,7 +697,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for LockS
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a LockScreenUnlockingEventArgs {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &LockScreenUnlockingEventArgs {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
