@@ -72,9 +72,9 @@ unsafe impl ::windows::core::Interface for IWiFiAdapterStatics {
 #[doc(hidden)]
 pub struct IWiFiAdapterStatics_Vtbl {
     pub base: ::windows::core::IInspectableVtbl,
-    #[cfg(feature = "Foundation_Collections")]
+    #[cfg(all(feature = "Foundation", feature = "Foundation_Collections"))]
     pub FindAllAdaptersAsync: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT,
-    #[cfg(not(feature = "Foundation_Collections"))]
+    #[cfg(not(all(feature = "Foundation", feature = "Foundation_Collections")))]
     FindAllAdaptersAsync: usize,
     pub GetDeviceSelector: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
     #[cfg(feature = "Foundation")]
@@ -168,7 +168,7 @@ pub struct IWiFiWpsConfigurationResult_Vtbl {
     #[cfg(not(feature = "Foundation_Collections"))]
     SupportedWpsKinds: usize,
 }
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct WiFiAccessStatus(pub i32);
@@ -199,16 +199,15 @@ impl ::core::fmt::Debug for WiFiAccessStatus {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiAccessStatus {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.WiFi.WiFiAccessStatus;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+impl ::windows::core::DefaultType for WiFiAccessStatus {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 pub struct WiFiAdapter(::windows::core::IUnknown);
 impl WiFiAdapter {
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Networking_Connectivity\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Networking_Connectivity'*"]
     #[cfg(feature = "Networking_Connectivity")]
     pub fn NetworkAdapter(&self) -> ::windows::core::Result<super::super::Networking::Connectivity::NetworkAdapter> {
         let this = self;
@@ -217,7 +216,7 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).NetworkAdapter)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Networking::Connectivity::NetworkAdapter>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn ScanAsync(&self) -> ::windows::core::Result<super::super::Foundation::IAsyncAction> {
         let this = self;
@@ -226,7 +225,7 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).ScanAsync)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::IAsyncAction>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn NetworkReport(&self) -> ::windows::core::Result<WiFiNetworkReport> {
         let this = self;
         unsafe {
@@ -234,7 +233,7 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).NetworkReport)(::core::mem::transmute_copy(this), &mut result__).from_abi::<WiFiNetworkReport>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn AvailableNetworksChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::TypedEventHandler<WiFiAdapter, ::windows::core::IInspectable>>>(&self, args: Param0) -> ::windows::core::Result<super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -243,13 +242,13 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).AvailableNetworksChanged)(::core::mem::transmute_copy(this), args.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveAvailableNetworksChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::EventRegistrationToken>>(&self, eventcookie: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveAvailableNetworksChanged)(::core::mem::transmute_copy(this), eventcookie.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn ConnectAsync<'a, Param0: ::windows::core::IntoParam<'a, WiFiAvailableNetwork>>(&self, availablenetwork: Param0, reconnectionkind: WiFiReconnectionKind) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<WiFiConnectionResult>> {
         let this = self;
@@ -258,7 +257,7 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).ConnectAsync)(::core::mem::transmute_copy(this), availablenetwork.into_param().abi(), reconnectionkind, &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<WiFiConnectionResult>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`, `\"Security_Credentials\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation', 'Security_Credentials'*"]
     #[cfg(all(feature = "Foundation", feature = "Security_Credentials"))]
     pub fn ConnectWithPasswordCredentialAsync<'a, Param0: ::windows::core::IntoParam<'a, WiFiAvailableNetwork>, Param2: ::windows::core::IntoParam<'a, super::super::Security::Credentials::PasswordCredential>>(&self, availablenetwork: Param0, reconnectionkind: WiFiReconnectionKind, passwordcredential: Param2) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<WiFiConnectionResult>> {
         let this = self;
@@ -267,7 +266,7 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).ConnectWithPasswordCredentialAsync)(::core::mem::transmute_copy(this), availablenetwork.into_param().abi(), reconnectionkind, passwordcredential.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<WiFiConnectionResult>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`, `\"Security_Credentials\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation', 'Security_Credentials'*"]
     #[cfg(all(feature = "Foundation", feature = "Security_Credentials"))]
     pub fn ConnectWithPasswordCredentialAndSsidAsync<'a, Param0: ::windows::core::IntoParam<'a, WiFiAvailableNetwork>, Param2: ::windows::core::IntoParam<'a, super::super::Security::Credentials::PasswordCredential>, Param3: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(&self, availablenetwork: Param0, reconnectionkind: WiFiReconnectionKind, passwordcredential: Param2, ssid: Param3) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<WiFiConnectionResult>> {
         let this = self;
@@ -276,12 +275,12 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).ConnectWithPasswordCredentialAndSsidAsync)(::core::mem::transmute_copy(this), availablenetwork.into_param().abi(), reconnectionkind, passwordcredential.into_param().abi(), ssid.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<WiFiConnectionResult>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn Disconnect(&self) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).Disconnect)(::core::mem::transmute_copy(this)).ok() }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn GetWpsConfigurationAsync<'a, Param0: ::windows::core::IntoParam<'a, WiFiAvailableNetwork>>(&self, availablenetwork: Param0) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<WiFiWpsConfigurationResult>> {
         let this = &::windows::core::Interface::cast::<IWiFiAdapter2>(self)?;
@@ -290,7 +289,7 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).GetWpsConfigurationAsync)(::core::mem::transmute_copy(this), availablenetwork.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<WiFiWpsConfigurationResult>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`, `\"Security_Credentials\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation', 'Security_Credentials'*"]
     #[cfg(all(feature = "Foundation", feature = "Security_Credentials"))]
     pub fn ConnectWithPasswordCredentialAndSsidAndConnectionMethodAsync<'a, Param0: ::windows::core::IntoParam<'a, WiFiAvailableNetwork>, Param2: ::windows::core::IntoParam<'a, super::super::Security::Credentials::PasswordCredential>, Param3: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(&self, availablenetwork: Param0, reconnectionkind: WiFiReconnectionKind, passwordcredential: Param2, ssid: Param3, connectionmethod: WiFiConnectionMethod) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<WiFiConnectionResult>> {
         let this = &::windows::core::Interface::cast::<IWiFiAdapter2>(self)?;
@@ -299,22 +298,22 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).ConnectWithPasswordCredentialAndSsidAndConnectionMethodAsync)(::core::mem::transmute_copy(this), availablenetwork.into_param().abi(), reconnectionkind, passwordcredential.into_param().abi(), ssid.into_param().abi(), connectionmethod, &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<WiFiConnectionResult>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation_Collections\"`*"]
-    #[cfg(feature = "Foundation_Collections")]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation', 'Foundation_Collections'*"]
+    #[cfg(all(feature = "Foundation", feature = "Foundation_Collections"))]
     pub fn FindAllAdaptersAsync() -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<super::super::Foundation::Collections::IVectorView<WiFiAdapter>>> {
         Self::IWiFiAdapterStatics(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).FindAllAdaptersAsync)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<super::super::Foundation::Collections::IVectorView<WiFiAdapter>>>(result__)
         })
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn GetDeviceSelector() -> ::windows::core::Result<::windows::core::HSTRING> {
         Self::IWiFiAdapterStatics(|this| unsafe {
             let mut result__: ::core::mem::ManuallyDrop<::windows::core::HSTRING> = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).GetDeviceSelector)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         })
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn FromIdAsync<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(deviceid: Param0) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<WiFiAdapter>> {
         Self::IWiFiAdapterStatics(|this| unsafe {
@@ -322,7 +321,7 @@ impl WiFiAdapter {
             (::windows::core::Interface::vtable(this).FromIdAsync)(::core::mem::transmute_copy(this), deviceid.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<WiFiAdapter>>(result__)
         })
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn RequestAccessAsync() -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<WiFiAccessStatus>> {
         Self::IWiFiAdapterStatics(|this| unsafe {
@@ -354,10 +353,6 @@ impl ::core::fmt::Debug for WiFiAdapter {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiAdapter {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.WiFi.WiFiAdapter;{a6c4e423-3d75-43a4-b9de-11e26b72d9b0})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for WiFiAdapter {
     type Vtable = IWiFiAdapter_Vtbl;
@@ -381,7 +376,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for WiFiAdapt
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a WiFiAdapter {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &WiFiAdapter {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -401,18 +396,18 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for WiFiA
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a WiFiAdapter {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &WiFiAdapter {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for WiFiAdapter {}
 unsafe impl ::core::marker::Sync for WiFiAdapter {}
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 pub struct WiFiAvailableNetwork(::windows::core::IUnknown);
 impl WiFiAvailableNetwork {
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Uptime(&self) -> ::windows::core::Result<super::super::Foundation::TimeSpan> {
         let this = self;
@@ -421,7 +416,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).Uptime)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn Ssid(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -429,7 +424,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).Ssid)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn Bssid(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -437,7 +432,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).Bssid)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn ChannelCenterFrequencyInKilohertz(&self) -> ::windows::core::Result<i32> {
         let this = self;
         unsafe {
@@ -445,7 +440,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).ChannelCenterFrequencyInKilohertz)(::core::mem::transmute_copy(this), &mut result__).from_abi::<i32>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn NetworkRssiInDecibelMilliwatts(&self) -> ::windows::core::Result<f64> {
         let this = self;
         unsafe {
@@ -453,7 +448,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).NetworkRssiInDecibelMilliwatts)(::core::mem::transmute_copy(this), &mut result__).from_abi::<f64>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn SignalBars(&self) -> ::windows::core::Result<u8> {
         let this = self;
         unsafe {
@@ -461,7 +456,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).SignalBars)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u8>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn NetworkKind(&self) -> ::windows::core::Result<WiFiNetworkKind> {
         let this = self;
         unsafe {
@@ -469,7 +464,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).NetworkKind)(::core::mem::transmute_copy(this), &mut result__).from_abi::<WiFiNetworkKind>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn PhyKind(&self) -> ::windows::core::Result<WiFiPhyKind> {
         let this = self;
         unsafe {
@@ -477,7 +472,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).PhyKind)(::core::mem::transmute_copy(this), &mut result__).from_abi::<WiFiPhyKind>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Networking_Connectivity\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Networking_Connectivity'*"]
     #[cfg(feature = "Networking_Connectivity")]
     pub fn SecuritySettings(&self) -> ::windows::core::Result<super::super::Networking::Connectivity::NetworkSecuritySettings> {
         let this = self;
@@ -486,7 +481,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).SecuritySettings)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Networking::Connectivity::NetworkSecuritySettings>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn BeaconInterval(&self) -> ::windows::core::Result<super::super::Foundation::TimeSpan> {
         let this = self;
@@ -495,7 +490,7 @@ impl WiFiAvailableNetwork {
             (::windows::core::Interface::vtable(this).BeaconInterval)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn IsWiFiDirect(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -522,10 +517,6 @@ impl ::core::fmt::Debug for WiFiAvailableNetwork {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiAvailableNetwork {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.WiFi.WiFiAvailableNetwork;{26e96246-183e-4704-9826-71b4a2f0f668})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for WiFiAvailableNetwork {
     type Vtable = IWiFiAvailableNetwork_Vtbl;
@@ -549,7 +540,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for WiFiAvail
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a WiFiAvailableNetwork {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &WiFiAvailableNetwork {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -569,14 +560,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for WiFiA
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a WiFiAvailableNetwork {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &WiFiAvailableNetwork {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for WiFiAvailableNetwork {}
 unsafe impl ::core::marker::Sync for WiFiAvailableNetwork {}
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct WiFiConnectionMethod(pub i32);
@@ -606,16 +597,15 @@ impl ::core::fmt::Debug for WiFiConnectionMethod {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiConnectionMethod {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.WiFi.WiFiConnectionMethod;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+impl ::windows::core::DefaultType for WiFiConnectionMethod {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 pub struct WiFiConnectionResult(::windows::core::IUnknown);
 impl WiFiConnectionResult {
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn ConnectionStatus(&self) -> ::windows::core::Result<WiFiConnectionStatus> {
         let this = self;
         unsafe {
@@ -642,10 +632,6 @@ impl ::core::fmt::Debug for WiFiConnectionResult {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiConnectionResult {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.WiFi.WiFiConnectionResult;{143bdfd9-c37d-40be-a5c8-857bce85a931})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for WiFiConnectionResult {
     type Vtable = IWiFiConnectionResult_Vtbl;
@@ -669,7 +655,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for WiFiConne
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a WiFiConnectionResult {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &WiFiConnectionResult {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -689,14 +675,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for WiFiC
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a WiFiConnectionResult {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &WiFiConnectionResult {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for WiFiConnectionResult {}
 unsafe impl ::core::marker::Sync for WiFiConnectionResult {}
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct WiFiConnectionStatus(pub i32);
@@ -730,12 +716,11 @@ impl ::core::fmt::Debug for WiFiConnectionStatus {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiConnectionStatus {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.WiFi.WiFiConnectionStatus;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+impl ::windows::core::DefaultType for WiFiConnectionStatus {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct WiFiNetworkKind(pub i32);
@@ -765,16 +750,15 @@ impl ::core::fmt::Debug for WiFiNetworkKind {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiNetworkKind {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.WiFi.WiFiNetworkKind;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+impl ::windows::core::DefaultType for WiFiNetworkKind {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 pub struct WiFiNetworkReport(::windows::core::IUnknown);
 impl WiFiNetworkReport {
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Timestamp(&self) -> ::windows::core::Result<super::super::Foundation::DateTime> {
         let this = self;
@@ -783,7 +767,7 @@ impl WiFiNetworkReport {
             (::windows::core::Interface::vtable(this).Timestamp)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::DateTime>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn AvailableNetworks(&self) -> ::windows::core::Result<super::super::Foundation::Collections::IVectorView<WiFiAvailableNetwork>> {
         let this = self;
@@ -811,10 +795,6 @@ impl ::core::fmt::Debug for WiFiNetworkReport {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiNetworkReport {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.WiFi.WiFiNetworkReport;{9524ded2-5911-445e-8194-be4f1a704895})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for WiFiNetworkReport {
     type Vtable = IWiFiNetworkReport_Vtbl;
@@ -838,7 +818,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for WiFiNetwo
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a WiFiNetworkReport {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &WiFiNetworkReport {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -858,14 +838,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for WiFiN
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a WiFiNetworkReport {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &WiFiNetworkReport {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for WiFiNetworkReport {}
 unsafe impl ::core::marker::Sync for WiFiNetworkReport {}
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct WiFiPhyKind(pub i32);
@@ -903,12 +883,11 @@ impl ::core::fmt::Debug for WiFiPhyKind {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiPhyKind {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.WiFi.WiFiPhyKind;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+impl ::windows::core::DefaultType for WiFiPhyKind {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct WiFiReconnectionKind(pub i32);
@@ -937,16 +916,15 @@ impl ::core::fmt::Debug for WiFiReconnectionKind {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiReconnectionKind {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.WiFi.WiFiReconnectionKind;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+impl ::windows::core::DefaultType for WiFiReconnectionKind {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 pub struct WiFiWpsConfigurationResult(::windows::core::IUnknown);
 impl WiFiWpsConfigurationResult {
-    #[doc = "*Required features: `\"Devices_WiFi\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi'*"]
     pub fn Status(&self) -> ::windows::core::Result<WiFiWpsConfigurationStatus> {
         let this = self;
         unsafe {
@@ -954,7 +932,7 @@ impl WiFiWpsConfigurationResult {
             (::windows::core::Interface::vtable(this).Status)(::core::mem::transmute_copy(this), &mut result__).from_abi::<WiFiWpsConfigurationStatus>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_WiFi\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'Devices_WiFi', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn SupportedWpsKinds(&self) -> ::windows::core::Result<super::super::Foundation::Collections::IVectorView<WiFiWpsKind>> {
         let this = self;
@@ -982,10 +960,6 @@ impl ::core::fmt::Debug for WiFiWpsConfigurationResult {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiWpsConfigurationResult {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.WiFi.WiFiWpsConfigurationResult;{67b49871-17ee-42d1-b14f-5a11f1226fb5})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for WiFiWpsConfigurationResult {
     type Vtable = IWiFiWpsConfigurationResult_Vtbl;
@@ -1009,7 +983,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for WiFiWpsCo
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a WiFiWpsConfigurationResult {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &WiFiWpsConfigurationResult {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -1029,14 +1003,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for WiFiW
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a WiFiWpsConfigurationResult {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &WiFiWpsConfigurationResult {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for WiFiWpsConfigurationResult {}
 unsafe impl ::core::marker::Sync for WiFiWpsConfigurationResult {}
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct WiFiWpsConfigurationStatus(pub i32);
@@ -1066,12 +1040,11 @@ impl ::core::fmt::Debug for WiFiWpsConfigurationStatus {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiWpsConfigurationStatus {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.WiFi.WiFiWpsConfigurationStatus;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_WiFi\"`*"]
+impl ::windows::core::DefaultType for WiFiWpsConfigurationStatus {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_WiFi'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct WiFiWpsKind(pub i32);
@@ -1104,10 +1077,9 @@ impl ::core::fmt::Debug for WiFiWpsKind {
 }
 unsafe impl ::windows::core::RuntimeType for WiFiWpsKind {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.WiFi.WiFiWpsKind;i4)");
+}
+impl ::windows::core::DefaultType for WiFiWpsKind {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
