@@ -1,6 +1,6 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
 #[repr(C)]
-#[doc = "*Required features: `\"Foundation_Numerics\"`*"]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Matrix3x2 {
     pub M11: f32,
     pub M12: f32,
@@ -25,10 +25,9 @@ unsafe impl ::windows::core::Abi for Matrix3x2 {
 }
 unsafe impl ::windows::core::RuntimeType for Matrix3x2 {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Foundation.Numerics.Matrix3x2;f4;f4;f4;f4;f4;f4)");
+}
+impl ::windows::core::DefaultType for Matrix3x2 {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 impl ::core::cmp::PartialEq for Matrix3x2 {
     fn eq(&self, other: &Self) -> bool {
@@ -183,7 +182,7 @@ impl ::core::ops::Mul<f32> for &Matrix3x2 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Foundation_Numerics\"`*"]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Matrix4x4 {
     pub M11: f32,
     pub M12: f32,
@@ -218,10 +217,9 @@ unsafe impl ::windows::core::Abi for Matrix4x4 {
 }
 unsafe impl ::windows::core::RuntimeType for Matrix4x4 {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Foundation.Numerics.Matrix4x4;f4;f4;f4;f4;f4;f4;f4;f4;f4;f4;f4;f4;f4;f4;f4;f4)");
+}
+impl ::windows::core::DefaultType for Matrix4x4 {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 impl ::core::cmp::PartialEq for Matrix4x4 {
     fn eq(&self, other: &Self) -> bool {
@@ -401,7 +399,7 @@ impl ::core::ops::Mul<f32> for &Matrix4x4 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Foundation_Numerics\"`*"]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Plane {
     pub Normal: Vector3,
     pub D: f32,
@@ -422,10 +420,9 @@ unsafe impl ::windows::core::Abi for Plane {
 }
 unsafe impl ::windows::core::RuntimeType for Plane {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Foundation.Numerics.Plane;struct(Windows.Foundation.Numerics.Vector3;f4;f4;f4);f4)");
+}
+impl ::windows::core::DefaultType for Plane {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 impl ::core::cmp::PartialEq for Plane {
     fn eq(&self, other: &Self) -> bool {
@@ -439,7 +436,7 @@ impl ::core::default::Default for Plane {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Foundation_Numerics\"`*"]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Quaternion {
     pub X: f32,
     pub Y: f32,
@@ -462,10 +459,9 @@ unsafe impl ::windows::core::Abi for Quaternion {
 }
 unsafe impl ::windows::core::RuntimeType for Quaternion {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Foundation.Numerics.Quaternion;f4;f4;f4;f4)");
+}
+impl ::windows::core::DefaultType for Quaternion {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 impl ::core::cmp::PartialEq for Quaternion {
     fn eq(&self, other: &Self) -> bool {
@@ -479,7 +475,7 @@ impl ::core::default::Default for Quaternion {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Foundation_Numerics\"`*"]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Rational {
     pub Numerator: u32,
     pub Denominator: u32,
@@ -500,10 +496,9 @@ unsafe impl ::windows::core::Abi for Rational {
 }
 unsafe impl ::windows::core::RuntimeType for Rational {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Foundation.Numerics.Rational;u4;u4)");
+}
+impl ::windows::core::DefaultType for Rational {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 impl ::core::cmp::PartialEq for Rational {
     fn eq(&self, other: &Self) -> bool {
@@ -517,7 +512,7 @@ impl ::core::default::Default for Rational {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Foundation_Numerics\"`*"]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Vector2 {
     pub X: f32,
     pub Y: f32,
@@ -538,10 +533,9 @@ unsafe impl ::windows::core::Abi for Vector2 {
 }
 unsafe impl ::windows::core::RuntimeType for Vector2 {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Foundation.Numerics.Vector2;f4;f4)");
+}
+impl ::windows::core::DefaultType for Vector2 {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 impl ::core::cmp::PartialEq for Vector2 {
     fn eq(&self, other: &Self) -> bool {
@@ -728,7 +722,7 @@ impl ::core::ops::Mul<f32> for &Vector2 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Foundation_Numerics\"`*"]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Vector3 {
     pub X: f32,
     pub Y: f32,
@@ -750,10 +744,9 @@ unsafe impl ::windows::core::Abi for Vector3 {
 }
 unsafe impl ::windows::core::RuntimeType for Vector3 {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Foundation.Numerics.Vector3;f4;f4;f4)");
+}
+impl ::windows::core::DefaultType for Vector3 {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 impl ::core::cmp::PartialEq for Vector3 {
     fn eq(&self, other: &Self) -> bool {
@@ -943,7 +936,7 @@ impl ::core::ops::Mul<f32> for &Vector3 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Foundation_Numerics\"`*"]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Vector4 {
     pub X: f32,
     pub Y: f32,
@@ -966,10 +959,9 @@ unsafe impl ::windows::core::Abi for Vector4 {
 }
 unsafe impl ::windows::core::RuntimeType for Vector4 {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Foundation.Numerics.Vector4;f4;f4;f4;f4)");
+}
+impl ::windows::core::DefaultType for Vector4 {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 impl ::core::cmp::PartialEq for Vector4 {
     fn eq(&self, other: &Self) -> bool {
