@@ -1,9 +1,9 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+#[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
 #[repr(transparent)]
 pub struct DateTimeFormatter(::windows::core::IUnknown);
 impl DateTimeFormatter {
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn Languages(&self) -> ::windows::core::Result<super::super::Foundation::Collections::IVectorView<::windows::core::HSTRING>> {
         let this = self;
@@ -12,7 +12,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).Languages)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::Collections::IVectorView<::windows::core::HSTRING>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn GeographicRegion(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -20,7 +20,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).GeographicRegion)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn Calendar(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -28,7 +28,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).Calendar)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn Clock(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -36,7 +36,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).Clock)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn NumeralSystem(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -44,12 +44,12 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).NumeralSystem)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn SetNumeralSystem<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(&self, value: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetNumeralSystem)(::core::mem::transmute_copy(this), value.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn Patterns(&self) -> ::windows::core::Result<super::super::Foundation::Collections::IVectorView<::windows::core::HSTRING>> {
         let this = self;
@@ -58,7 +58,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).Patterns)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Foundation::Collections::IVectorView<::windows::core::HSTRING>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn Template(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -66,7 +66,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).Template)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Format<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::DateTime>>(&self, value: Param0) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
@@ -75,7 +75,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).Format)(::core::mem::transmute_copy(this), value.into_param().abi(), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn IncludeYear(&self) -> ::windows::core::Result<YearFormat> {
         let this = self;
         unsafe {
@@ -83,7 +83,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).IncludeYear)(::core::mem::transmute_copy(this), &mut result__).from_abi::<YearFormat>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn IncludeMonth(&self) -> ::windows::core::Result<MonthFormat> {
         let this = self;
         unsafe {
@@ -91,7 +91,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).IncludeMonth)(::core::mem::transmute_copy(this), &mut result__).from_abi::<MonthFormat>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn IncludeDayOfWeek(&self) -> ::windows::core::Result<DayOfWeekFormat> {
         let this = self;
         unsafe {
@@ -99,7 +99,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).IncludeDayOfWeek)(::core::mem::transmute_copy(this), &mut result__).from_abi::<DayOfWeekFormat>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn IncludeDay(&self) -> ::windows::core::Result<DayFormat> {
         let this = self;
         unsafe {
@@ -107,7 +107,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).IncludeDay)(::core::mem::transmute_copy(this), &mut result__).from_abi::<DayFormat>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn IncludeHour(&self) -> ::windows::core::Result<HourFormat> {
         let this = self;
         unsafe {
@@ -115,7 +115,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).IncludeHour)(::core::mem::transmute_copy(this), &mut result__).from_abi::<HourFormat>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn IncludeMinute(&self) -> ::windows::core::Result<MinuteFormat> {
         let this = self;
         unsafe {
@@ -123,7 +123,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).IncludeMinute)(::core::mem::transmute_copy(this), &mut result__).from_abi::<MinuteFormat>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn IncludeSecond(&self) -> ::windows::core::Result<SecondFormat> {
         let this = self;
         unsafe {
@@ -131,7 +131,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).IncludeSecond)(::core::mem::transmute_copy(this), &mut result__).from_abi::<SecondFormat>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn ResolvedLanguage(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -139,7 +139,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).ResolvedLanguage)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn ResolvedGeographicRegion(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -147,7 +147,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).ResolvedGeographicRegion)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn FormatUsingTimeZone<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::DateTime>, Param1: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(&self, datetime: Param0, timezoneid: Param1) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = &::windows::core::Interface::cast::<IDateTimeFormatter2>(self)?;
@@ -156,14 +156,14 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).FormatUsingTimeZone)(::core::mem::transmute_copy(this), datetime.into_param().abi(), timezoneid.into_param().abi(), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn CreateDateTimeFormatter<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(formattemplate: Param0) -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterFactory(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).CreateDateTimeFormatter)(::core::mem::transmute_copy(this), formattemplate.into_param().abi(), &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn CreateDateTimeFormatterLanguages<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param1: ::windows::core::IntoParam<'a, super::super::Foundation::Collections::IIterable<::windows::core::HSTRING>>>(formattemplate: Param0, languages: Param1) -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterFactory(|this| unsafe {
@@ -171,7 +171,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).CreateDateTimeFormatterLanguages)(::core::mem::transmute_copy(this), formattemplate.into_param().abi(), languages.into_param().abi(), &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn CreateDateTimeFormatterContext<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param1: ::windows::core::IntoParam<'a, super::super::Foundation::Collections::IIterable<::windows::core::HSTRING>>, Param2: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param3: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param4: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(formattemplate: Param0, languages: Param1, geographicregion: Param2, calendar: Param3, clock: Param4) -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterFactory(|this| unsafe {
@@ -179,21 +179,21 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).CreateDateTimeFormatterContext)(::core::mem::transmute_copy(this), formattemplate.into_param().abi(), languages.into_param().abi(), geographicregion.into_param().abi(), calendar.into_param().abi(), clock.into_param().abi(), &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn CreateDateTimeFormatterDate(yearformat: YearFormat, monthformat: MonthFormat, dayformat: DayFormat, dayofweekformat: DayOfWeekFormat) -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterFactory(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).CreateDateTimeFormatterDate)(::core::mem::transmute_copy(this), yearformat, monthformat, dayformat, dayofweekformat, &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn CreateDateTimeFormatterTime(hourformat: HourFormat, minuteformat: MinuteFormat, secondformat: SecondFormat) -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterFactory(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).CreateDateTimeFormatterTime)(::core::mem::transmute_copy(this), hourformat, minuteformat, secondformat, &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn CreateDateTimeFormatterDateTimeLanguages<'a, Param7: ::windows::core::IntoParam<'a, super::super::Foundation::Collections::IIterable<::windows::core::HSTRING>>>(yearformat: YearFormat, monthformat: MonthFormat, dayformat: DayFormat, dayofweekformat: DayOfWeekFormat, hourformat: HourFormat, minuteformat: MinuteFormat, secondformat: SecondFormat, languages: Param7) -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterFactory(|this| unsafe {
@@ -201,7 +201,7 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).CreateDateTimeFormatterDateTimeLanguages)(::core::mem::transmute_copy(this), yearformat, monthformat, dayformat, dayofweekformat, hourformat, minuteformat, secondformat, languages.into_param().abi(), &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn CreateDateTimeFormatterDateTimeContext<'a, Param7: ::windows::core::IntoParam<'a, super::super::Foundation::Collections::IIterable<::windows::core::HSTRING>>, Param8: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param9: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param10: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(yearformat: YearFormat, monthformat: MonthFormat, dayformat: DayFormat, dayofweekformat: DayOfWeekFormat, hourformat: HourFormat, minuteformat: MinuteFormat, secondformat: SecondFormat, languages: Param7, geographicregion: Param8, calendar: Param9, clock: Param10) -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterFactory(|this| unsafe {
@@ -209,28 +209,28 @@ impl DateTimeFormatter {
             (::windows::core::Interface::vtable(this).CreateDateTimeFormatterDateTimeContext)(::core::mem::transmute_copy(this), yearformat, monthformat, dayformat, dayofweekformat, hourformat, minuteformat, secondformat, languages.into_param().abi(), geographicregion.into_param().abi(), calendar.into_param().abi(), clock.into_param().abi(), &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn LongDate() -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterStatics(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).LongDate)(::core::mem::transmute_copy(this), &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn LongTime() -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterStatics(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).LongTime)(::core::mem::transmute_copy(this), &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn ShortDate() -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterStatics(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).ShortDate)(::core::mem::transmute_copy(this), &mut result__).from_abi::<DateTimeFormatter>(result__)
         })
     }
-    #[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+    #[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
     pub fn ShortTime() -> ::windows::core::Result<DateTimeFormatter> {
         Self::IDateTimeFormatterStatics(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
@@ -266,10 +266,6 @@ impl ::core::fmt::Debug for DateTimeFormatter {
 }
 unsafe impl ::windows::core::RuntimeType for DateTimeFormatter {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Globalization.DateTimeFormatting.DateTimeFormatter;{95eeca10-73e0-4e4b-a183-3d6ad0ba35ec})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for DateTimeFormatter {
     type Vtable = IDateTimeFormatter_Vtbl;
@@ -293,7 +289,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for DateTimeF
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a DateTimeFormatter {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &DateTimeFormatter {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -313,14 +309,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for DateT
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a DateTimeFormatter {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &DateTimeFormatter {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for DateTimeFormatter {}
 unsafe impl ::core::marker::Sync for DateTimeFormatter {}
-#[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+#[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct DayFormat(pub i32);
@@ -349,12 +345,11 @@ impl ::core::fmt::Debug for DayFormat {
 }
 unsafe impl ::windows::core::RuntimeType for DayFormat {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Globalization.DateTimeFormatting.DayFormat;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+impl ::windows::core::DefaultType for DayFormat {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct DayOfWeekFormat(pub i32);
@@ -385,12 +380,11 @@ impl ::core::fmt::Debug for DayOfWeekFormat {
 }
 unsafe impl ::windows::core::RuntimeType for DayOfWeekFormat {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Globalization.DateTimeFormatting.DayOfWeekFormat;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+impl ::windows::core::DefaultType for DayOfWeekFormat {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HourFormat(pub i32);
@@ -419,10 +413,9 @@ impl ::core::fmt::Debug for HourFormat {
 }
 unsafe impl ::windows::core::RuntimeType for HourFormat {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Globalization.DateTimeFormatting.HourFormat;i4)");
+}
+impl ::windows::core::DefaultType for HourFormat {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 #[doc(hidden)]
 #[repr(transparent)]
@@ -526,7 +519,7 @@ pub struct IDateTimeFormatterStatics_Vtbl {
     pub ShortDate: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT,
     pub ShortTime: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+#[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct MinuteFormat(pub i32);
@@ -555,12 +548,11 @@ impl ::core::fmt::Debug for MinuteFormat {
 }
 unsafe impl ::windows::core::RuntimeType for MinuteFormat {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Globalization.DateTimeFormatting.MinuteFormat;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+impl ::windows::core::DefaultType for MinuteFormat {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct MonthFormat(pub i32);
@@ -592,12 +584,11 @@ impl ::core::fmt::Debug for MonthFormat {
 }
 unsafe impl ::windows::core::RuntimeType for MonthFormat {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Globalization.DateTimeFormatting.MonthFormat;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+impl ::windows::core::DefaultType for MonthFormat {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct SecondFormat(pub i32);
@@ -626,12 +617,11 @@ impl ::core::fmt::Debug for SecondFormat {
 }
 unsafe impl ::windows::core::RuntimeType for SecondFormat {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Globalization.DateTimeFormatting.SecondFormat;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Globalization_DateTimeFormatting\"`*"]
+impl ::windows::core::DefaultType for SecondFormat {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Globalization_DateTimeFormatting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct YearFormat(pub i32);
@@ -662,10 +652,9 @@ impl ::core::fmt::Debug for YearFormat {
 }
 unsafe impl ::windows::core::RuntimeType for YearFormat {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Globalization.DateTimeFormatting.YearFormat;i4)");
+}
+impl ::windows::core::DefaultType for YearFormat {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
