@@ -13,22 +13,22 @@ pub mod Radial;
 pub mod Touch;
 #[cfg(feature = "Win32_UI_Input_XboxController")]
 pub mod XboxController;
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn DefRawInputProc(parawinput: &[*const RAWINPUT], cbsizeheader: u32) -> super::super::Foundation::LRESULT {
+pub unsafe fn DefRawInputProc(parawinput: *const *const RAWINPUT, ninput: i32, cbsizeheader: u32) -> super::super::Foundation::LRESULT {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
             fn DefRawInputProc(parawinput: *const *const RAWINPUT, ninput: i32, cbsizeheader: u32) -> super::super::Foundation::LRESULT;
         }
-        ::core::mem::transmute(DefRawInputProc(::core::mem::transmute(::windows::core::as_ptr_or_null(parawinput)), parawinput.len() as _, ::core::mem::transmute(cbsizeheader)))
+        ::core::mem::transmute(DefRawInputProc(::core::mem::transmute(parawinput), ::core::mem::transmute(ninput), ::core::mem::transmute(cbsizeheader)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn GetCIMSSM(inputmessagesource: *mut INPUT_MESSAGE_SOURCE) -> super::super::Foundation::BOOL {
@@ -43,7 +43,7 @@ pub unsafe fn GetCIMSSM(inputmessagesource: *mut INPUT_MESSAGE_SOURCE) -> super:
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn GetCurrentInputMessageSource(inputmessagesource: *mut INPUT_MESSAGE_SOURCE) -> super::super::Foundation::BOOL {
@@ -58,7 +58,7 @@ pub unsafe fn GetCurrentInputMessageSource(inputmessagesource: *mut INPUT_MESSAG
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn GetRawInputBuffer(pdata: *mut RAWINPUT, pcbsize: *mut u32, cbsizeheader: u32) -> u32 {
@@ -73,7 +73,7 @@ pub unsafe fn GetRawInputBuffer(pdata: *mut RAWINPUT, pcbsize: *mut u32, cbsizeh
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 #[inline]
 pub unsafe fn GetRawInputData<'a, Param0: ::windows::core::IntoParam<'a, HRAWINPUT>>(hrawinput: Param0, uicommand: RAW_INPUT_DATA_COMMAND_FLAGS, pdata: *mut ::core::ffi::c_void, pcbsize: *mut u32, cbsizeheader: u32) -> u32 {
     #[cfg(windows)]
@@ -87,7 +87,7 @@ pub unsafe fn GetRawInputData<'a, Param0: ::windows::core::IntoParam<'a, HRAWINP
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn GetRawInputDeviceInfoA<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::HANDLE>>(hdevice: Param0, uicommand: RAW_INPUT_DEVICE_INFO_COMMAND, pdata: *mut ::core::ffi::c_void, pcbsize: *mut u32) -> u32 {
@@ -102,7 +102,7 @@ pub unsafe fn GetRawInputDeviceInfoA<'a, Param0: ::windows::core::IntoParam<'a,
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn GetRawInputDeviceInfoW<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::HANDLE>>(hdevice: Param0, uicommand: RAW_INPUT_DEVICE_INFO_COMMAND, pdata: *mut ::core::ffi::c_void, pcbsize: *mut u32) -> u32 {
@@ -117,7 +117,7 @@ pub unsafe fn GetRawInputDeviceInfoW<'a, Param0: ::windows::core::IntoParam<'a,
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn GetRawInputDeviceList(prawinputdevicelist: *mut RAWINPUTDEVICELIST, puinumdevices: *mut u32, cbsize: u32) -> u32 {
@@ -132,7 +132,7 @@ pub unsafe fn GetRawInputDeviceList(prawinputdevicelist: *mut RAWINPUTDEVICELIST
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn GetRegisteredRawInputDevices(prawinputdevices: *mut RAWINPUTDEVICE, puinumdevices: *mut u32, cbsize: u32) -> u32 {
@@ -181,21 +181,21 @@ impl ::core::fmt::Debug for HRAWINPUT {
 unsafe impl ::windows::core::Abi for HRAWINPUT {
     type Abi = Self;
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct INPUT_MESSAGE_DEVICE_TYPE(pub i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMDT_UNAVAILABLE: INPUT_MESSAGE_DEVICE_TYPE = INPUT_MESSAGE_DEVICE_TYPE(0i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMDT_KEYBOARD: INPUT_MESSAGE_DEVICE_TYPE = INPUT_MESSAGE_DEVICE_TYPE(1i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMDT_MOUSE: INPUT_MESSAGE_DEVICE_TYPE = INPUT_MESSAGE_DEVICE_TYPE(2i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMDT_TOUCH: INPUT_MESSAGE_DEVICE_TYPE = INPUT_MESSAGE_DEVICE_TYPE(4i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMDT_PEN: INPUT_MESSAGE_DEVICE_TYPE = INPUT_MESSAGE_DEVICE_TYPE(8i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMDT_TOUCHPAD: INPUT_MESSAGE_DEVICE_TYPE = INPUT_MESSAGE_DEVICE_TYPE(16i32);
 impl ::core::marker::Copy for INPUT_MESSAGE_DEVICE_TYPE {}
 impl ::core::clone::Clone for INPUT_MESSAGE_DEVICE_TYPE {
@@ -216,17 +216,17 @@ impl ::core::fmt::Debug for INPUT_MESSAGE_DEVICE_TYPE {
         f.debug_tuple("INPUT_MESSAGE_DEVICE_TYPE").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct INPUT_MESSAGE_ORIGIN_ID(pub i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMO_UNAVAILABLE: INPUT_MESSAGE_ORIGIN_ID = INPUT_MESSAGE_ORIGIN_ID(0i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMO_HARDWARE: INPUT_MESSAGE_ORIGIN_ID = INPUT_MESSAGE_ORIGIN_ID(1i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMO_INJECTED: INPUT_MESSAGE_ORIGIN_ID = INPUT_MESSAGE_ORIGIN_ID(2i32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const IMO_SYSTEM: INPUT_MESSAGE_ORIGIN_ID = INPUT_MESSAGE_ORIGIN_ID(4i32);
 impl ::core::marker::Copy for INPUT_MESSAGE_ORIGIN_ID {}
 impl ::core::clone::Clone for INPUT_MESSAGE_ORIGIN_ID {
@@ -248,7 +248,7 @@ impl ::core::fmt::Debug for INPUT_MESSAGE_ORIGIN_ID {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub struct INPUT_MESSAGE_SOURCE {
     pub deviceType: INPUT_MESSAGE_DEVICE_TYPE,
     pub originId: INPUT_MESSAGE_ORIGIN_ID,
@@ -279,7 +279,7 @@ impl ::core::default::Default for INPUT_MESSAGE_SOURCE {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub struct RAWHID {
     pub dwSizeHid: u32,
     pub dwCount: u32,
@@ -311,7 +311,7 @@ impl ::core::default::Default for RAWHID {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct RAWINPUT {
     pub header: RAWINPUTHEADER,
@@ -344,7 +344,7 @@ impl ::core::default::Default for RAWINPUT {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union RAWINPUT_0 {
     pub mouse: RAWMOUSE,
@@ -378,7 +378,7 @@ impl ::core::default::Default for RAWINPUT_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct RAWINPUTDEVICE {
     pub usUsagePage: u16,
@@ -419,7 +419,7 @@ impl ::core::default::Default for RAWINPUTDEVICE {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct RAWINPUTDEVICELIST {
     pub hDevice: super::super::Foundation::HANDLE,
@@ -457,29 +457,29 @@ impl ::core::default::Default for RAWINPUTDEVICELIST {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct RAWINPUTDEVICE_FLAGS(pub u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_REMOVE: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(1u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_EXCLUDE: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(16u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_PAGEONLY: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(32u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_NOLEGACY: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(48u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_INPUTSINK: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(256u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_CAPTUREMOUSE: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(512u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_NOHOTKEYS: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(512u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_APPKEYS: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(1024u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_EXINPUTSINK: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(4096u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDEV_DEVNOTIFY: RAWINPUTDEVICE_FLAGS = RAWINPUTDEVICE_FLAGS(8192u32);
 impl ::core::marker::Copy for RAWINPUTDEVICE_FLAGS {}
 impl ::core::clone::Clone for RAWINPUTDEVICE_FLAGS {
@@ -501,7 +501,7 @@ impl ::core::fmt::Debug for RAWINPUTDEVICE_FLAGS {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct RAWINPUTHEADER {
     pub dwType: u32,
@@ -542,7 +542,7 @@ impl ::core::default::Default for RAWINPUTHEADER {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub struct RAWKEYBOARD {
     pub MakeCode: u16,
     pub Flags: u16,
@@ -577,7 +577,7 @@ impl ::core::default::Default for RAWKEYBOARD {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub struct RAWMOUSE {
     pub usFlags: u16,
     pub Anonymous: RAWMOUSE_0,
@@ -607,7 +607,7 @@ impl ::core::default::Default for RAWMOUSE {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub union RAWMOUSE_0 {
     pub ulButtons: u32,
     pub Anonymous: RAWMOUSE_0_0,
@@ -633,7 +633,7 @@ impl ::core::default::Default for RAWMOUSE_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub struct RAWMOUSE_0_0 {
     pub usButtonFlags: u16,
     pub usButtonData: u16,
@@ -663,13 +663,13 @@ impl ::core::default::Default for RAWMOUSE_0_0 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct RAW_INPUT_DATA_COMMAND_FLAGS(pub u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RID_HEADER: RAW_INPUT_DATA_COMMAND_FLAGS = RAW_INPUT_DATA_COMMAND_FLAGS(268435461u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RID_INPUT: RAW_INPUT_DATA_COMMAND_FLAGS = RAW_INPUT_DATA_COMMAND_FLAGS(268435459u32);
 impl ::core::marker::Copy for RAW_INPUT_DATA_COMMAND_FLAGS {}
 impl ::core::clone::Clone for RAW_INPUT_DATA_COMMAND_FLAGS {
@@ -690,15 +690,15 @@ impl ::core::fmt::Debug for RAW_INPUT_DATA_COMMAND_FLAGS {
         f.debug_tuple("RAW_INPUT_DATA_COMMAND_FLAGS").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct RAW_INPUT_DEVICE_INFO_COMMAND(pub u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDI_PREPARSEDDATA: RAW_INPUT_DEVICE_INFO_COMMAND = RAW_INPUT_DEVICE_INFO_COMMAND(536870917u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDI_DEVICENAME: RAW_INPUT_DEVICE_INFO_COMMAND = RAW_INPUT_DEVICE_INFO_COMMAND(536870919u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIDI_DEVICEINFO: RAW_INPUT_DEVICE_INFO_COMMAND = RAW_INPUT_DEVICE_INFO_COMMAND(536870923u32);
 impl ::core::marker::Copy for RAW_INPUT_DEVICE_INFO_COMMAND {}
 impl ::core::clone::Clone for RAW_INPUT_DEVICE_INFO_COMMAND {
@@ -720,7 +720,7 @@ impl ::core::fmt::Debug for RAW_INPUT_DEVICE_INFO_COMMAND {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct RID_DEVICE_INFO {
     pub cbSize: u32,
@@ -754,7 +754,7 @@ impl ::core::default::Default for RID_DEVICE_INFO {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union RID_DEVICE_INFO_0 {
     pub mouse: RID_DEVICE_INFO_MOUSE,
@@ -788,7 +788,7 @@ impl ::core::default::Default for RID_DEVICE_INFO_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub struct RID_DEVICE_INFO_HID {
     pub dwVendorId: u32,
     pub dwProductId: u32,
@@ -822,7 +822,7 @@ impl ::core::default::Default for RID_DEVICE_INFO_HID {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub struct RID_DEVICE_INFO_KEYBOARD {
     pub dwType: u32,
     pub dwSubType: u32,
@@ -857,7 +857,7 @@ impl ::core::default::Default for RID_DEVICE_INFO_KEYBOARD {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct RID_DEVICE_INFO_MOUSE {
     pub dwId: u32,
@@ -897,15 +897,15 @@ impl ::core::default::Default for RID_DEVICE_INFO_MOUSE {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct RID_DEVICE_INFO_TYPE(pub u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIM_TYPEMOUSE: RID_DEVICE_INFO_TYPE = RID_DEVICE_INFO_TYPE(0u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIM_TYPEKEYBOARD: RID_DEVICE_INFO_TYPE = RID_DEVICE_INFO_TYPE(1u32);
-#[doc = "*Required features: `\"Win32_UI_Input\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input'*"]
 pub const RIM_TYPEHID: RID_DEVICE_INFO_TYPE = RID_DEVICE_INFO_TYPE(2u32);
 impl ::core::marker::Copy for RID_DEVICE_INFO_TYPE {}
 impl ::core::clone::Clone for RID_DEVICE_INFO_TYPE {
@@ -926,17 +926,17 @@ impl ::core::fmt::Debug for RID_DEVICE_INFO_TYPE {
         f.debug_tuple("RID_DEVICE_INFO_TYPE").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: `\"Win32_UI_Input\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn RegisterRawInputDevices(prawinputdevices: &[RAWINPUTDEVICE], cbsize: u32) -> super::super::Foundation::BOOL {
+pub unsafe fn RegisterRawInputDevices(prawinputdevices: *const RAWINPUTDEVICE, uinumdevices: u32, cbsize: u32) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
             fn RegisterRawInputDevices(prawinputdevices: *const RAWINPUTDEVICE, uinumdevices: u32, cbsize: u32) -> super::super::Foundation::BOOL;
         }
-        ::core::mem::transmute(RegisterRawInputDevices(::core::mem::transmute(::windows::core::as_ptr_or_null(prawinputdevices)), prawinputdevices.len() as _, ::core::mem::transmute(cbsize)))
+        ::core::mem::transmute(RegisterRawInputDevices(::core::mem::transmute(prawinputdevices), ::core::mem::transmute(uinumdevices), ::core::mem::transmute(cbsize)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
