@@ -1,9 +1,9 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+#[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
 #[repr(transparent)]
 pub struct Geofence(::windows::core::IUnknown);
 impl Geofence {
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn StartTime(&self) -> ::windows::core::Result<super::super::super::Foundation::DateTime> {
         let this = self;
@@ -12,7 +12,7 @@ impl Geofence {
             (::windows::core::Interface::vtable(this).StartTime)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::DateTime>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn Duration(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -21,7 +21,7 @@ impl Geofence {
             (::windows::core::Interface::vtable(this).Duration)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn DwellTime(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -30,7 +30,7 @@ impl Geofence {
             (::windows::core::Interface::vtable(this).DwellTime)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn Id(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
@@ -38,7 +38,7 @@ impl Geofence {
             (::windows::core::Interface::vtable(this).Id)(::core::mem::transmute_copy(this), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn MonitoredStates(&self) -> ::windows::core::Result<MonitoredGeofenceStates> {
         let this = self;
         unsafe {
@@ -46,7 +46,7 @@ impl Geofence {
             (::windows::core::Interface::vtable(this).MonitoredStates)(::core::mem::transmute_copy(this), &mut result__).from_abi::<MonitoredGeofenceStates>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn Geoshape(&self) -> ::windows::core::Result<super::IGeoshape> {
         let this = self;
         unsafe {
@@ -54,7 +54,7 @@ impl Geofence {
             (::windows::core::Interface::vtable(this).Geoshape)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::IGeoshape>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn SingleUse(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -62,21 +62,21 @@ impl Geofence {
             (::windows::core::Interface::vtable(this).SingleUse)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn Create<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param1: ::windows::core::IntoParam<'a, super::IGeoshape>>(id: Param0, geoshape: Param1) -> ::windows::core::Result<Geofence> {
         Self::IGeofenceFactory(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).Create)(::core::mem::transmute_copy(this), id.into_param().abi(), geoshape.into_param().abi(), &mut result__).from_abi::<Geofence>(result__)
         })
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn CreateWithMonitorStates<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param1: ::windows::core::IntoParam<'a, super::IGeoshape>>(id: Param0, geoshape: Param1, monitoredstates: MonitoredGeofenceStates, singleuse: bool) -> ::windows::core::Result<Geofence> {
         Self::IGeofenceFactory(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).CreateWithMonitorStates)(::core::mem::transmute_copy(this), id.into_param().abi(), geoshape.into_param().abi(), monitoredstates, singleuse, &mut result__).from_abi::<Geofence>(result__)
         })
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn CreateWithMonitorStatesAndDwellTime<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param1: ::windows::core::IntoParam<'a, super::IGeoshape>, Param4: ::windows::core::IntoParam<'a, super::super::super::Foundation::TimeSpan>>(id: Param0, geoshape: Param1, monitoredstates: MonitoredGeofenceStates, singleuse: bool, dwelltime: Param4) -> ::windows::core::Result<Geofence> {
         Self::IGeofenceFactory(|this| unsafe {
@@ -84,7 +84,7 @@ impl Geofence {
             (::windows::core::Interface::vtable(this).CreateWithMonitorStatesAndDwellTime)(::core::mem::transmute_copy(this), id.into_param().abi(), geoshape.into_param().abi(), monitoredstates, singleuse, dwelltime.into_param().abi(), &mut result__).from_abi::<Geofence>(result__)
         })
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn CreateWithMonitorStatesDwellTimeStartTimeAndDuration<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>, Param1: ::windows::core::IntoParam<'a, super::IGeoshape>, Param4: ::windows::core::IntoParam<'a, super::super::super::Foundation::TimeSpan>, Param5: ::windows::core::IntoParam<'a, super::super::super::Foundation::DateTime>, Param6: ::windows::core::IntoParam<'a, super::super::super::Foundation::TimeSpan>>(id: Param0, geoshape: Param1, monitoredstates: MonitoredGeofenceStates, singleuse: bool, dwelltime: Param4, starttime: Param5, duration: Param6) -> ::windows::core::Result<Geofence> {
         Self::IGeofenceFactory(|this| unsafe {
@@ -116,6 +116,10 @@ impl ::core::fmt::Debug for Geofence {
 }
 unsafe impl ::windows::core::RuntimeType for Geofence {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.Geolocation.Geofencing.Geofence;{9c090823-edb8-47e0-8245-5bf61d321f2d})");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for Geofence {
     type Vtable = IGeofence_Vtbl;
@@ -139,7 +143,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for Geofence
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &Geofence {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a Geofence {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -159,18 +163,18 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Geofe
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &Geofence {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a Geofence {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for Geofence {}
 unsafe impl ::core::marker::Sync for Geofence {}
-#[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+#[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
 #[repr(transparent)]
 pub struct GeofenceMonitor(::windows::core::IUnknown);
 impl GeofenceMonitor {
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn Status(&self) -> ::windows::core::Result<GeofenceMonitorStatus> {
         let this = self;
         unsafe {
@@ -178,7 +182,7 @@ impl GeofenceMonitor {
             (::windows::core::Interface::vtable(this).Status)(::core::mem::transmute_copy(this), &mut result__).from_abi::<GeofenceMonitorStatus>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation_Collections'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation_Collections\"`*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn Geofences(&self) -> ::windows::core::Result<super::super::super::Foundation::Collections::IVector<Geofence>> {
         let this = self;
@@ -187,7 +191,7 @@ impl GeofenceMonitor {
             (::windows::core::Interface::vtable(this).Geofences)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Collections::IVector<Geofence>>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn LastKnownGeoposition(&self) -> ::windows::core::Result<super::Geoposition> {
         let this = self;
         unsafe {
@@ -195,7 +199,7 @@ impl GeofenceMonitor {
             (::windows::core::Interface::vtable(this).LastKnownGeoposition)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::Geoposition>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn GeofenceStateChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::TypedEventHandler<GeofenceMonitor, ::windows::core::IInspectable>>>(&self, eventhandler: Param0) -> ::windows::core::Result<super::super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -204,13 +208,13 @@ impl GeofenceMonitor {
             (::windows::core::Interface::vtable(this).GeofenceStateChanged)(::core::mem::transmute_copy(this), eventhandler.into_param().abi(), &mut result__).from_abi::<super::super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveGeofenceStateChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveGeofenceStateChanged)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation_Collections'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation_Collections\"`*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn ReadReports(&self) -> ::windows::core::Result<super::super::super::Foundation::Collections::IVectorView<GeofenceStateChangeReport>> {
         let this = self;
@@ -219,7 +223,7 @@ impl GeofenceMonitor {
             (::windows::core::Interface::vtable(this).ReadReports)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Collections::IVectorView<GeofenceStateChangeReport>>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn StatusChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::TypedEventHandler<GeofenceMonitor, ::windows::core::IInspectable>>>(&self, eventhandler: Param0) -> ::windows::core::Result<super::super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -228,13 +232,13 @@ impl GeofenceMonitor {
             (::windows::core::Interface::vtable(this).StatusChanged)(::core::mem::transmute_copy(this), eventhandler.into_param().abi(), &mut result__).from_abi::<super::super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing', 'Foundation'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveStatusChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveStatusChanged)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn Current() -> ::windows::core::Result<GeofenceMonitor> {
         Self::IGeofenceMonitorStatics(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
@@ -265,6 +269,10 @@ impl ::core::fmt::Debug for GeofenceMonitor {
 }
 unsafe impl ::windows::core::RuntimeType for GeofenceMonitor {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.Geolocation.Geofencing.GeofenceMonitor;{4c0f5f78-1c1f-4621-bbbd-833b92247226})");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for GeofenceMonitor {
     type Vtable = IGeofenceMonitor_Vtbl;
@@ -288,7 +296,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for GeofenceM
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &GeofenceMonitor {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a GeofenceMonitor {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -308,14 +316,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Geofe
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &GeofenceMonitor {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a GeofenceMonitor {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for GeofenceMonitor {}
 unsafe impl ::core::marker::Sync for GeofenceMonitor {}
-#[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+#[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct GeofenceMonitorStatus(pub i32);
@@ -348,11 +356,12 @@ impl ::core::fmt::Debug for GeofenceMonitorStatus {
 }
 unsafe impl ::windows::core::RuntimeType for GeofenceMonitorStatus {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.Geolocation.Geofencing.GeofenceMonitorStatus;i4)");
-}
-impl ::windows::core::DefaultType for GeofenceMonitorStatus {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
-#[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+#[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct GeofenceRemovalReason(pub i32);
@@ -381,11 +390,12 @@ impl ::core::fmt::Debug for GeofenceRemovalReason {
 }
 unsafe impl ::windows::core::RuntimeType for GeofenceRemovalReason {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.Geolocation.Geofencing.GeofenceRemovalReason;i4)");
-}
-impl ::windows::core::DefaultType for GeofenceRemovalReason {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
-#[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+#[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct GeofenceState(pub u32);
@@ -444,15 +454,16 @@ impl ::core::ops::Not for GeofenceState {
 }
 unsafe impl ::windows::core::RuntimeType for GeofenceState {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.Geolocation.Geofencing.GeofenceState;u4)");
-}
-impl ::windows::core::DefaultType for GeofenceState {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
-#[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+#[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
 #[repr(transparent)]
 pub struct GeofenceStateChangeReport(::windows::core::IUnknown);
 impl GeofenceStateChangeReport {
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn NewState(&self) -> ::windows::core::Result<GeofenceState> {
         let this = self;
         unsafe {
@@ -460,7 +471,7 @@ impl GeofenceStateChangeReport {
             (::windows::core::Interface::vtable(this).NewState)(::core::mem::transmute_copy(this), &mut result__).from_abi::<GeofenceState>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn Geofence(&self) -> ::windows::core::Result<Geofence> {
         let this = self;
         unsafe {
@@ -468,7 +479,7 @@ impl GeofenceStateChangeReport {
             (::windows::core::Interface::vtable(this).Geofence)(::core::mem::transmute_copy(this), &mut result__).from_abi::<Geofence>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn Geoposition(&self) -> ::windows::core::Result<super::Geoposition> {
         let this = self;
         unsafe {
@@ -476,7 +487,7 @@ impl GeofenceStateChangeReport {
             (::windows::core::Interface::vtable(this).Geoposition)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::Geoposition>(result__)
         }
     }
-    #[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+    #[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
     pub fn RemovalReason(&self) -> ::windows::core::Result<GeofenceRemovalReason> {
         let this = self;
         unsafe {
@@ -503,6 +514,10 @@ impl ::core::fmt::Debug for GeofenceStateChangeReport {
 }
 unsafe impl ::windows::core::RuntimeType for GeofenceStateChangeReport {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.Geolocation.Geofencing.GeofenceStateChangeReport;{9a243c18-2464-4c89-be05-b3ffff5babc5})");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for GeofenceStateChangeReport {
     type Vtable = IGeofenceStateChangeReport_Vtbl;
@@ -526,7 +541,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for GeofenceS
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &GeofenceStateChangeReport {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a GeofenceStateChangeReport {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -546,7 +561,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Geofe
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &GeofenceStateChangeReport {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a GeofenceStateChangeReport {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -670,7 +685,7 @@ pub struct IGeofenceStateChangeReport_Vtbl {
     pub Geoposition: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT,
     pub RemovalReason: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut GeofenceRemovalReason) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: 'Devices_Geolocation_Geofencing'*"]
+#[doc = "*Required features: `\"Devices_Geolocation_Geofencing\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct MonitoredGeofenceStates(pub u32);
@@ -729,9 +744,10 @@ impl ::core::ops::Not for MonitoredGeofenceStates {
 }
 unsafe impl ::windows::core::RuntimeType for MonitoredGeofenceStates {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates;u4)");
-}
-impl ::windows::core::DefaultType for MonitoredGeofenceStates {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
