@@ -1,22 +1,22 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: 'Web_Http_Filters'*"]
+#[doc = "*Required features: `\"Web_Http_Filters\"`*"]
 #[repr(transparent)]
 pub struct HttpBaseProtocolFilter(::windows::core::IUnknown);
 impl HttpBaseProtocolFilter {
     pub fn new() -> ::windows::core::Result<Self> {
-        Self::IActivationFactory(|f| f.activate_instance::<Self>())
+        Self::IActivationFactory(|f| f.ActivateInstance::<Self>())
     }
     fn IActivationFactory<R, F: FnOnce(&::windows::core::IActivationFactory) -> ::windows::core::Result<R>>(callback: F) -> ::windows::core::Result<R> {
         static mut SHARED: ::windows::core::FactoryCache<HttpBaseProtocolFilter, ::windows::core::IActivationFactory> = ::windows::core::FactoryCache::new();
         unsafe { SHARED.call(callback) }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn Close(&self) -> ::windows::core::Result<()> {
         let this = &::windows::core::Interface::cast::<super::super::super::Foundation::IClosable>(self)?;
         unsafe { (::windows::core::Interface::vtable(this).Close)(::core::mem::transmute_copy(this)).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn AllowAutoRedirect(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -24,12 +24,12 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).AllowAutoRedirect)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetAllowAutoRedirect(&self, value: bool) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetAllowAutoRedirect)(::core::mem::transmute_copy(this), value).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn AllowUI(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -37,12 +37,12 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).AllowUI)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetAllowUI(&self, value: bool) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetAllowUI)(::core::mem::transmute_copy(this), value).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn AutomaticDecompression(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -50,12 +50,12 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).AutomaticDecompression)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetAutomaticDecompression(&self, value: bool) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetAutomaticDecompression)(::core::mem::transmute_copy(this), value).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn CacheControl(&self) -> ::windows::core::Result<HttpCacheControl> {
         let this = self;
         unsafe {
@@ -63,7 +63,7 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).CacheControl)(::core::mem::transmute_copy(this), &mut result__).from_abi::<HttpCacheControl>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn CookieManager(&self) -> ::windows::core::Result<super::HttpCookieManager> {
         let this = self;
         unsafe {
@@ -71,7 +71,7 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).CookieManager)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::HttpCookieManager>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Security_Cryptography_Certificates'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Security_Cryptography_Certificates\"`*"]
     #[cfg(feature = "Security_Cryptography_Certificates")]
     pub fn ClientCertificate(&self) -> ::windows::core::Result<super::super::super::Security::Cryptography::Certificates::Certificate> {
         let this = self;
@@ -80,13 +80,13 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).ClientCertificate)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Security::Cryptography::Certificates::Certificate>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Security_Cryptography_Certificates'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Security_Cryptography_Certificates\"`*"]
     #[cfg(feature = "Security_Cryptography_Certificates")]
     pub fn SetClientCertificate<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Security::Cryptography::Certificates::Certificate>>(&self, value: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetClientCertificate)(::core::mem::transmute_copy(this), value.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation_Collections', 'Security_Cryptography_Certificates'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation_Collections\"`, `\"Security_Cryptography_Certificates\"`*"]
     #[cfg(all(feature = "Foundation_Collections", feature = "Security_Cryptography_Certificates"))]
     pub fn IgnorableServerCertificateErrors(&self) -> ::windows::core::Result<super::super::super::Foundation::Collections::IVector<super::super::super::Security::Cryptography::Certificates::ChainValidationResult>> {
         let this = self;
@@ -95,7 +95,7 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).IgnorableServerCertificateErrors)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Collections::IVector<super::super::super::Security::Cryptography::Certificates::ChainValidationResult>>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn MaxConnectionsPerServer(&self) -> ::windows::core::Result<u32> {
         let this = self;
         unsafe {
@@ -103,12 +103,12 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).MaxConnectionsPerServer)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u32>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetMaxConnectionsPerServer(&self, value: u32) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetMaxConnectionsPerServer)(::core::mem::transmute_copy(this), value).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Security_Credentials'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Security_Credentials\"`*"]
     #[cfg(feature = "Security_Credentials")]
     pub fn ProxyCredential(&self) -> ::windows::core::Result<super::super::super::Security::Credentials::PasswordCredential> {
         let this = self;
@@ -117,13 +117,13 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).ProxyCredential)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Security::Credentials::PasswordCredential>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Security_Credentials'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Security_Credentials\"`*"]
     #[cfg(feature = "Security_Credentials")]
     pub fn SetProxyCredential<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Security::Credentials::PasswordCredential>>(&self, value: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetProxyCredential)(::core::mem::transmute_copy(this), value.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Security_Credentials'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Security_Credentials\"`*"]
     #[cfg(feature = "Security_Credentials")]
     pub fn ServerCredential(&self) -> ::windows::core::Result<super::super::super::Security::Credentials::PasswordCredential> {
         let this = self;
@@ -132,13 +132,13 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).ServerCredential)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Security::Credentials::PasswordCredential>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Security_Credentials'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Security_Credentials\"`*"]
     #[cfg(feature = "Security_Credentials")]
     pub fn SetServerCredential<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Security::Credentials::PasswordCredential>>(&self, value: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetServerCredential)(::core::mem::transmute_copy(this), value.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn UseProxy(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -146,12 +146,12 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).UseProxy)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetUseProxy(&self, value: bool) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetUseProxy)(::core::mem::transmute_copy(this), value).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn MaxVersion(&self) -> ::windows::core::Result<super::HttpVersion> {
         let this = &::windows::core::Interface::cast::<IHttpBaseProtocolFilter2>(self)?;
         unsafe {
@@ -159,12 +159,12 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).MaxVersion)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::HttpVersion>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetMaxVersion(&self, value: super::HttpVersion) -> ::windows::core::Result<()> {
         let this = &::windows::core::Interface::cast::<IHttpBaseProtocolFilter2>(self)?;
         unsafe { (::windows::core::Interface::vtable(this).SetMaxVersion)(::core::mem::transmute_copy(this), value).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn CookieUsageBehavior(&self) -> ::windows::core::Result<HttpCookieUsageBehavior> {
         let this = &::windows::core::Interface::cast::<IHttpBaseProtocolFilter3>(self)?;
         unsafe {
@@ -172,12 +172,12 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).CookieUsageBehavior)(::core::mem::transmute_copy(this), &mut result__).from_abi::<HttpCookieUsageBehavior>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetCookieUsageBehavior(&self, value: HttpCookieUsageBehavior) -> ::windows::core::Result<()> {
         let this = &::windows::core::Interface::cast::<IHttpBaseProtocolFilter3>(self)?;
         unsafe { (::windows::core::Interface::vtable(this).SetCookieUsageBehavior)(::core::mem::transmute_copy(this), value).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn ServerCustomValidationRequested<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::TypedEventHandler<HttpBaseProtocolFilter, HttpServerCustomValidationRequestedEventArgs>>>(&self, handler: Param0) -> ::windows::core::Result<super::super::super::Foundation::EventRegistrationToken> {
         let this = &::windows::core::Interface::cast::<IHttpBaseProtocolFilter4>(self)?;
@@ -186,18 +186,18 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).ServerCustomValidationRequested)(::core::mem::transmute_copy(this), handler.into_param().abi(), &mut result__).from_abi::<super::super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveServerCustomValidationRequested<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = &::windows::core::Interface::cast::<IHttpBaseProtocolFilter4>(self)?;
         unsafe { (::windows::core::Interface::vtable(this).RemoveServerCustomValidationRequested)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn ClearAuthenticationCache(&self) -> ::windows::core::Result<()> {
         let this = &::windows::core::Interface::cast::<IHttpBaseProtocolFilter4>(self)?;
         unsafe { (::windows::core::Interface::vtable(this).ClearAuthenticationCache)(::core::mem::transmute_copy(this)).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'System'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"System\"`*"]
     #[cfg(feature = "System")]
     pub fn User(&self) -> ::windows::core::Result<super::super::super::System::User> {
         let this = &::windows::core::Interface::cast::<IHttpBaseProtocolFilter5>(self)?;
@@ -206,7 +206,7 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).User)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::System::User>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'System'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"System\"`*"]
     #[cfg(feature = "System")]
     pub fn CreateForUser<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::System::User>>(user: Param0) -> ::windows::core::Result<HttpBaseProtocolFilter> {
         Self::IHttpBaseProtocolFilterStatics(|this| unsafe {
@@ -214,7 +214,7 @@ impl HttpBaseProtocolFilter {
             (::windows::core::Interface::vtable(this).CreateForUser)(::core::mem::transmute_copy(this), user.into_param().abi(), &mut result__).from_abi::<HttpBaseProtocolFilter>(result__)
         })
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn SendRequestAsync<'a, Param0: ::windows::core::IntoParam<'a, super::HttpRequestMessage>>(&self, request: Param0) -> ::windows::core::Result<super::super::super::Foundation::IAsyncOperationWithProgress<super::HttpResponseMessage, super::HttpProgress>> {
         let this = &::windows::core::Interface::cast::<IHttpFilter>(self)?;
@@ -247,6 +247,10 @@ impl ::core::fmt::Debug for HttpBaseProtocolFilter {
 }
 unsafe impl ::windows::core::RuntimeType for HttpBaseProtocolFilter {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Web.Http.Filters.HttpBaseProtocolFilter;{71c89b09-e131-4b54-a53c-eb43ff37e9bb})");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for HttpBaseProtocolFilter {
     type Vtable = IHttpBaseProtocolFilter_Vtbl;
@@ -270,7 +274,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for HttpBaseP
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &HttpBaseProtocolFilter {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a HttpBaseProtocolFilter {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -290,7 +294,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for HttpB
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &HttpBaseProtocolFilter {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a HttpBaseProtocolFilter {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -345,11 +349,11 @@ impl<'a> ::windows::core::IntoParam<'a, IHttpFilter> for &HttpBaseProtocolFilter
 }
 unsafe impl ::core::marker::Send for HttpBaseProtocolFilter {}
 unsafe impl ::core::marker::Sync for HttpBaseProtocolFilter {}
-#[doc = "*Required features: 'Web_Http_Filters'*"]
+#[doc = "*Required features: `\"Web_Http_Filters\"`*"]
 #[repr(transparent)]
 pub struct HttpCacheControl(::windows::core::IUnknown);
 impl HttpCacheControl {
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn ReadBehavior(&self) -> ::windows::core::Result<HttpCacheReadBehavior> {
         let this = self;
         unsafe {
@@ -357,12 +361,12 @@ impl HttpCacheControl {
             (::windows::core::Interface::vtable(this).ReadBehavior)(::core::mem::transmute_copy(this), &mut result__).from_abi::<HttpCacheReadBehavior>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetReadBehavior(&self, value: HttpCacheReadBehavior) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetReadBehavior)(::core::mem::transmute_copy(this), value).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn WriteBehavior(&self) -> ::windows::core::Result<HttpCacheWriteBehavior> {
         let this = self;
         unsafe {
@@ -370,7 +374,7 @@ impl HttpCacheControl {
             (::windows::core::Interface::vtable(this).WriteBehavior)(::core::mem::transmute_copy(this), &mut result__).from_abi::<HttpCacheWriteBehavior>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn SetWriteBehavior(&self, value: HttpCacheWriteBehavior) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).SetWriteBehavior)(::core::mem::transmute_copy(this), value).ok() }
@@ -394,6 +398,10 @@ impl ::core::fmt::Debug for HttpCacheControl {
 }
 unsafe impl ::windows::core::RuntimeType for HttpCacheControl {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Web.Http.Filters.HttpCacheControl;{c77e1cb4-3cea-4eb5-ac85-04e186e63ab7})");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for HttpCacheControl {
     type Vtable = IHttpCacheControl_Vtbl;
@@ -417,7 +425,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for HttpCache
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &HttpCacheControl {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a HttpCacheControl {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -437,14 +445,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for HttpC
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &HttpCacheControl {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a HttpCacheControl {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for HttpCacheControl {}
 unsafe impl ::core::marker::Sync for HttpCacheControl {}
-#[doc = "*Required features: 'Web_Http_Filters'*"]
+#[doc = "*Required features: `\"Web_Http_Filters\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HttpCacheReadBehavior(pub i32);
@@ -475,11 +483,12 @@ impl ::core::fmt::Debug for HttpCacheReadBehavior {
 }
 unsafe impl ::windows::core::RuntimeType for HttpCacheReadBehavior {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Web.Http.Filters.HttpCacheReadBehavior;i4)");
-}
-impl ::windows::core::DefaultType for HttpCacheReadBehavior {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
-#[doc = "*Required features: 'Web_Http_Filters'*"]
+#[doc = "*Required features: `\"Web_Http_Filters\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HttpCacheWriteBehavior(pub i32);
@@ -508,11 +517,12 @@ impl ::core::fmt::Debug for HttpCacheWriteBehavior {
 }
 unsafe impl ::windows::core::RuntimeType for HttpCacheWriteBehavior {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Web.Http.Filters.HttpCacheWriteBehavior;i4)");
-}
-impl ::windows::core::DefaultType for HttpCacheWriteBehavior {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
-#[doc = "*Required features: 'Web_Http_Filters'*"]
+#[doc = "*Required features: `\"Web_Http_Filters\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HttpCookieUsageBehavior(pub i32);
@@ -541,15 +551,16 @@ impl ::core::fmt::Debug for HttpCookieUsageBehavior {
 }
 unsafe impl ::windows::core::RuntimeType for HttpCookieUsageBehavior {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Web.Http.Filters.HttpCookieUsageBehavior;i4)");
-}
-impl ::windows::core::DefaultType for HttpCookieUsageBehavior {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
-#[doc = "*Required features: 'Web_Http_Filters'*"]
+#[doc = "*Required features: `\"Web_Http_Filters\"`*"]
 #[repr(transparent)]
 pub struct HttpServerCustomValidationRequestedEventArgs(::windows::core::IUnknown);
 impl HttpServerCustomValidationRequestedEventArgs {
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn RequestMessage(&self) -> ::windows::core::Result<super::HttpRequestMessage> {
         let this = self;
         unsafe {
@@ -557,7 +568,7 @@ impl HttpServerCustomValidationRequestedEventArgs {
             (::windows::core::Interface::vtable(this).RequestMessage)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::HttpRequestMessage>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Security_Cryptography_Certificates'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Security_Cryptography_Certificates\"`*"]
     #[cfg(feature = "Security_Cryptography_Certificates")]
     pub fn ServerCertificate(&self) -> ::windows::core::Result<super::super::super::Security::Cryptography::Certificates::Certificate> {
         let this = self;
@@ -566,7 +577,7 @@ impl HttpServerCustomValidationRequestedEventArgs {
             (::windows::core::Interface::vtable(this).ServerCertificate)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Security::Cryptography::Certificates::Certificate>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Networking_Sockets'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Networking_Sockets\"`*"]
     #[cfg(feature = "Networking_Sockets")]
     pub fn ServerCertificateErrorSeverity(&self) -> ::windows::core::Result<super::super::super::Networking::Sockets::SocketSslErrorSeverity> {
         let this = self;
@@ -575,7 +586,7 @@ impl HttpServerCustomValidationRequestedEventArgs {
             (::windows::core::Interface::vtable(this).ServerCertificateErrorSeverity)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Networking::Sockets::SocketSslErrorSeverity>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation_Collections', 'Security_Cryptography_Certificates'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation_Collections\"`, `\"Security_Cryptography_Certificates\"`*"]
     #[cfg(all(feature = "Foundation_Collections", feature = "Security_Cryptography_Certificates"))]
     pub fn ServerCertificateErrors(&self) -> ::windows::core::Result<super::super::super::Foundation::Collections::IVectorView<super::super::super::Security::Cryptography::Certificates::ChainValidationResult>> {
         let this = self;
@@ -584,7 +595,7 @@ impl HttpServerCustomValidationRequestedEventArgs {
             (::windows::core::Interface::vtable(this).ServerCertificateErrors)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Collections::IVectorView<super::super::super::Security::Cryptography::Certificates::ChainValidationResult>>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation_Collections', 'Security_Cryptography_Certificates'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation_Collections\"`, `\"Security_Cryptography_Certificates\"`*"]
     #[cfg(all(feature = "Foundation_Collections", feature = "Security_Cryptography_Certificates"))]
     pub fn ServerIntermediateCertificates(&self) -> ::windows::core::Result<super::super::super::Foundation::Collections::IVectorView<super::super::super::Security::Cryptography::Certificates::Certificate>> {
         let this = self;
@@ -593,12 +604,12 @@ impl HttpServerCustomValidationRequestedEventArgs {
             (::windows::core::Interface::vtable(this).ServerIntermediateCertificates)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Collections::IVectorView<super::super::super::Security::Cryptography::Certificates::Certificate>>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`*"]
     pub fn Reject(&self) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).Reject)(::core::mem::transmute_copy(this)).ok() }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn GetDeferral(&self) -> ::windows::core::Result<super::super::super::Foundation::Deferral> {
         let this = self;
@@ -626,6 +637,10 @@ impl ::core::fmt::Debug for HttpServerCustomValidationRequestedEventArgs {
 }
 unsafe impl ::windows::core::RuntimeType for HttpServerCustomValidationRequestedEventArgs {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Web.Http.Filters.HttpServerCustomValidationRequestedEventArgs;{3165fe32-e7dd-48b7-a361-939c750e63cc})");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for HttpServerCustomValidationRequestedEventArgs {
     type Vtable = IHttpServerCustomValidationRequestedEventArgs_Vtbl;
@@ -649,7 +664,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for HttpServe
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &HttpServerCustomValidationRequestedEventArgs {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a HttpServerCustomValidationRequestedEventArgs {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -669,7 +684,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for HttpS
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &HttpServerCustomValidationRequestedEventArgs {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a HttpServerCustomValidationRequestedEventArgs {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -825,11 +840,11 @@ pub struct IHttpCacheControl_Vtbl {
     pub WriteBehavior: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut HttpCacheWriteBehavior) -> ::windows::core::HRESULT,
     pub SetWriteBehavior: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, value: HttpCacheWriteBehavior) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: 'Web_Http_Filters'*"]
+#[doc = "*Required features: `\"Web_Http_Filters\"`*"]
 #[repr(transparent)]
 pub struct IHttpFilter(::windows::core::IUnknown);
 impl IHttpFilter {
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn SendRequestAsync<'a, Param0: ::windows::core::IntoParam<'a, super::HttpRequestMessage>>(&self, request: Param0) -> ::windows::core::Result<super::super::super::Foundation::IAsyncOperationWithProgress<super::HttpResponseMessage, super::HttpProgress>> {
         let this = self;
@@ -838,7 +853,7 @@ impl IHttpFilter {
             (::windows::core::Interface::vtable(this).SendRequestAsync)(::core::mem::transmute_copy(this), request.into_param().abi(), &mut result__).from_abi::<super::super::super::Foundation::IAsyncOperationWithProgress<super::HttpResponseMessage, super::HttpProgress>>(result__)
         }
     }
-    #[doc = "*Required features: 'Web_Http_Filters', 'Foundation'*"]
+    #[doc = "*Required features: `\"Web_Http_Filters\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn Close(&self) -> ::windows::core::Result<()> {
         let this = &::windows::core::Interface::cast::<super::super::super::Foundation::IClosable>(self)?;
@@ -860,7 +875,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IHttpFilt
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IHttpFilter {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IHttpFilter {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -880,7 +895,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for IHttp
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &IHttpFilter {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a IHttpFilter {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -929,6 +944,10 @@ impl ::core::fmt::Debug for IHttpFilter {
 }
 unsafe impl ::windows::core::RuntimeType for IHttpFilter {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"{a4cb6dd5-0902-439e-bfd7-e12552b165ce}");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for IHttpFilter {
     type Vtable = IHttpFilter_Vtbl;
