@@ -1,9 +1,9 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct CMD_ENTRY {
-    pub pwszCmdToken: super::super::Foundation::PWSTR,
+    pub pwszCmdToken: ::windows::core::PCWSTR,
     pub pfnCmdHandler: PFN_HANDLE_CMD,
     pub dwShortCmdHelpToken: u32,
     pub dwCmdHlpToken: u32,
@@ -43,10 +43,10 @@ impl ::core::default::Default for CMD_ENTRY {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct CMD_GROUP_ENTRY {
-    pub pwszCmdGroupToken: super::super::Foundation::PWSTR,
+    pub pwszCmdGroupToken: ::windows::core::PCWSTR,
     pub dwShortCmdHelpToken: u32,
     pub ulCmdGroupSize: u32,
     pub dwFlags: u32,
@@ -85,115 +85,115 @@ impl ::core::default::Default for CMD_GROUP_ENTRY {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const DEFAULT_CONTEXT_PRIORITY: u32 = 100u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_CMD_NOT_FOUND: u32 = 15004u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_CONTEXT_ALREADY_REGISTERED: u32 = 15019u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_CONTINUE_IN_PARENT_CONTEXT: u32 = 15016u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_DLL_LOAD_FAILED: u32 = 15006u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_ENTRY_PT_NOT_FOUND: u32 = 15005u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_HELPER_ALREADY_REGISTERED: u32 = 15018u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_INIT_DISPLAY: u32 = 15007u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_INVALID_OPTION_TAG: u32 = 15009u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_INVALID_OPTION_VALUE: u32 = 15014u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_INVALID_SYNTAX: u32 = 15001u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_MISSING_OPTION: u32 = 15011u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_NO_CHANGE: u32 = 15003u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_NO_ENTRIES: u32 = 15000u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_NO_TAG: u32 = 15010u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_OKAY: u32 = 15015u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_PARSING_FAILURE: u32 = 15020u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_PROTOCOL_NOT_IN_TRANSPORT: u32 = 15002u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_SHOW_USAGE: u32 = 15013u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_SUPPRESS_OUTPUT: u32 = 15017u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_TAG_ALREADY_PRESENT: u32 = 15008u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const ERROR_TRANSPORT_NOT_PRESENT: u32 = 15012u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const GET_RESOURCE_STRING_FN_NAME: &'static str = "GetResourceString";
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const MAX_NAME_LEN: u32 = 48u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn MatchEnumTag<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::HANDLE>, Param1: ::windows::core::IntoParam<'a, super::super::Foundation::PWSTR>>(hmodule: Param0, pwcarg: Param1, dwnumarg: u32, penumtable: *const TOKEN_VALUE, pdwvalue: *mut u32) -> u32 {
+pub unsafe fn MatchEnumTag<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::HANDLE>, Param1: ::windows::core::IntoParam<'a, ::windows::core::PCWSTR>>(hmodule: Param0, pwcarg: Param1, dwnumarg: u32, penumtable: *const TOKEN_VALUE, pdwvalue: *mut u32) -> u32 {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn MatchEnumTag(hmodule: super::super::Foundation::HANDLE, pwcarg: super::super::Foundation::PWSTR, dwnumarg: u32, penumtable: *const TOKEN_VALUE, pdwvalue: *mut u32) -> u32;
+            fn MatchEnumTag(hmodule: super::super::Foundation::HANDLE, pwcarg: ::windows::core::PCWSTR, dwnumarg: u32, penumtable: *const TOKEN_VALUE, pdwvalue: *mut u32) -> u32;
         }
         ::core::mem::transmute(MatchEnumTag(hmodule.into_param().abi(), pwcarg.into_param().abi(), ::core::mem::transmute(dwnumarg), ::core::mem::transmute(penumtable), ::core::mem::transmute(pdwvalue)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn MatchToken<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::PWSTR>, Param1: ::windows::core::IntoParam<'a, super::super::Foundation::PWSTR>>(pwszusertoken: Param0, pwszcmdtoken: Param1) -> super::super::Foundation::BOOL {
+pub unsafe fn MatchToken<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::PCWSTR>, Param1: ::windows::core::IntoParam<'a, ::windows::core::PCWSTR>>(pwszusertoken: Param0, pwszcmdtoken: Param1) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn MatchToken(pwszusertoken: super::super::Foundation::PWSTR, pwszcmdtoken: super::super::Foundation::PWSTR) -> super::super::Foundation::BOOL;
+            fn MatchToken(pwszusertoken: ::windows::core::PCWSTR, pwszcmdtoken: ::windows::core::PCWSTR) -> super::super::Foundation::BOOL;
         }
         ::core::mem::transmute(MatchToken(pwszusertoken.into_param().abi(), pwszcmdtoken.into_param().abi()))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_ARG_DELIMITER: &'static str = "=";
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_CMD_DELIMITER: &'static str = " ";
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_ERROR_BASE: u32 = 15000u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_ERROR_END: u32 = 15019u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_MAX_CMD_TOKEN_LENGTH: u32 = 128u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_MAX_TOKEN_LENGTH: u32 = 64u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_VERSION_50: u32 = 20480u32;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct NS_CMD_FLAGS(pub i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const CMD_FLAG_PRIVATE: NS_CMD_FLAGS = NS_CMD_FLAGS(1i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const CMD_FLAG_INTERACTIVE: NS_CMD_FLAGS = NS_CMD_FLAGS(2i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const CMD_FLAG_LOCAL: NS_CMD_FLAGS = NS_CMD_FLAGS(8i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const CMD_FLAG_ONLINE: NS_CMD_FLAGS = NS_CMD_FLAGS(16i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const CMD_FLAG_HIDDEN: NS_CMD_FLAGS = NS_CMD_FLAGS(32i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const CMD_FLAG_LIMIT_MASK: NS_CMD_FLAGS = NS_CMD_FLAGS(65535i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const CMD_FLAG_PRIORITY: NS_CMD_FLAGS = NS_CMD_FLAGS(-2147483648i32);
 impl ::core::marker::Copy for NS_CMD_FLAGS {}
 impl ::core::clone::Clone for NS_CMD_FLAGS {
@@ -215,11 +215,11 @@ impl ::core::fmt::Debug for NS_CMD_FLAGS {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct NS_CONTEXT_ATTRIBUTES {
     pub Anonymous: NS_CONTEXT_ATTRIBUTES_0,
-    pub pwszContext: super::super::Foundation::PWSTR,
+    pub pwszContext: ::windows::core::PWSTR,
     pub guidHelper: ::windows::core::GUID,
     pub dwFlags: u32,
     pub ulPriority: u32,
@@ -260,7 +260,7 @@ impl ::core::default::Default for NS_CONTEXT_ATTRIBUTES {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union NS_CONTEXT_ATTRIBUTES_0 {
     pub Anonymous: NS_CONTEXT_ATTRIBUTES_0_0,
@@ -293,7 +293,7 @@ impl ::core::default::Default for NS_CONTEXT_ATTRIBUTES_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct NS_CONTEXT_ATTRIBUTES_0_0 {
     pub dwVersion: u32,
@@ -331,19 +331,19 @@ impl ::core::default::Default for NS_CONTEXT_ATTRIBUTES_0_0 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct NS_EVENTS(pub i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_EVENT_LOOP: NS_EVENTS = NS_EVENTS(65536i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_EVENT_LAST_N: NS_EVENTS = NS_EVENTS(1i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_EVENT_LAST_SECS: NS_EVENTS = NS_EVENTS(2i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_EVENT_FROM_N: NS_EVENTS = NS_EVENTS(4i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_EVENT_FROM_START: NS_EVENTS = NS_EVENTS(8i32);
 impl ::core::marker::Copy for NS_EVENTS {}
 impl ::core::clone::Clone for NS_EVENTS {
@@ -364,10 +364,10 @@ impl ::core::fmt::Debug for NS_EVENTS {
         f.debug_tuple("NS_EVENTS").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_GET_EVENT_IDS_FN_NAME: &'static str = "GetEventIds";
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub struct NS_HELPER_ATTRIBUTES {
     pub Anonymous: NS_HELPER_ATTRIBUTES_0,
     pub guidHelper: ::windows::core::GUID,
@@ -395,7 +395,7 @@ impl ::core::default::Default for NS_HELPER_ATTRIBUTES {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub union NS_HELPER_ATTRIBUTES_0 {
     pub Anonymous: NS_HELPER_ATTRIBUTES_0_0,
     pub _ullAlign: u64,
@@ -421,7 +421,7 @@ impl ::core::default::Default for NS_HELPER_ATTRIBUTES_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub struct NS_HELPER_ATTRIBUTES_0_0 {
     pub dwVersion: u32,
     pub dwReserved: u32,
@@ -451,19 +451,19 @@ impl ::core::default::Default for NS_HELPER_ATTRIBUTES_0_0 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct NS_MODE_CHANGE(pub i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_COMMIT: NS_MODE_CHANGE = NS_MODE_CHANGE(0i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_UNCOMMIT: NS_MODE_CHANGE = NS_MODE_CHANGE(1i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_FLUSH: NS_MODE_CHANGE = NS_MODE_CHANGE(2i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_COMMIT_STATE: NS_MODE_CHANGE = NS_MODE_CHANGE(3i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NETSH_SAVE: NS_MODE_CHANGE = NS_MODE_CHANGE(4i32);
 impl ::core::marker::Copy for NS_MODE_CHANGE {}
 impl ::core::clone::Clone for NS_MODE_CHANGE {
@@ -484,17 +484,17 @@ impl ::core::fmt::Debug for NS_MODE_CHANGE {
         f.debug_tuple("NS_MODE_CHANGE").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct NS_REQS(pub i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_REQ_ZERO: NS_REQS = NS_REQS(0i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_REQ_PRESENT: NS_REQS = NS_REQS(1i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_REQ_ALLOW_MULTIPLE: NS_REQS = NS_REQS(2i32);
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub const NS_REQ_ONE_OR_MORE: NS_REQS = NS_REQS(3i32);
 impl ::core::marker::Copy for NS_REQS {}
 impl ::core::clone::Clone for NS_REQS {
@@ -515,47 +515,44 @@ impl ::core::fmt::Debug for NS_REQS {
         f.debug_tuple("NS_REQS").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-pub type PFN_HANDLE_CMD = ::core::option::Option<unsafe extern "system" fn(pwszmachine: super::super::Foundation::PWSTR, ppwcarguments: *mut super::super::Foundation::PWSTR, dwcurrentindex: u32, dwargcount: u32, dwflags: u32, pvdata: *const ::core::ffi::c_void, pbdone: *mut super::super::Foundation::BOOL) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
-pub type PGET_RESOURCE_STRING_FN = ::core::option::Option<unsafe extern "system" fn(dwmsgid: u32, lpbuffer: super::super::Foundation::PWSTR, nbuffermax: u32) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+pub type PFN_HANDLE_CMD = ::core::option::Option<unsafe extern "system" fn(pwszmachine: ::windows::core::PCWSTR, ppwcarguments: *mut ::windows::core::PWSTR, dwcurrentindex: u32, dwargcount: u32, dwflags: u32, pvdata: *const ::core::ffi::c_void, pbdone: *mut super::super::Foundation::BOOL) -> u32>;
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
+pub type PGET_RESOURCE_STRING_FN = ::core::option::Option<unsafe extern "system" fn(dwmsgid: u32, lpbuffer: ::windows::core::PCWSTR, nbuffermax: u32) -> u32>;
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub type PNS_CONTEXT_COMMIT_FN = ::core::option::Option<unsafe extern "system" fn(dwaction: u32) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
-pub type PNS_CONTEXT_CONNECT_FN = ::core::option::Option<unsafe extern "system" fn(pwszmachine: super::super::Foundation::PWSTR) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
-pub type PNS_CONTEXT_DUMP_FN = ::core::option::Option<unsafe extern "system" fn(pwszrouter: super::super::Foundation::PWSTR, ppwcarguments: *const super::super::Foundation::PWSTR, dwargcount: u32, pvdata: *const ::core::ffi::c_void) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
+pub type PNS_CONTEXT_CONNECT_FN = ::core::option::Option<unsafe extern "system" fn(pwszmachine: ::windows::core::PCWSTR) -> u32>;
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
+pub type PNS_CONTEXT_DUMP_FN = ::core::option::Option<unsafe extern "system" fn(pwszrouter: ::windows::core::PCWSTR, ppwcarguments: *const ::windows::core::PWSTR, dwargcount: u32, pvdata: *const ::core::ffi::c_void) -> u32>;
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub type PNS_DLL_INIT_FN = ::core::option::Option<unsafe extern "system" fn(dwnetshversion: u32, preserved: *mut ::core::ffi::c_void) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub type PNS_DLL_STOP_FN = ::core::option::Option<unsafe extern "system" fn(dwreserved: u32) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub type PNS_HELPER_START_FN = ::core::option::Option<unsafe extern "system" fn(pguidparent: *const ::windows::core::GUID, dwversion: u32) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub type PNS_HELPER_STOP_FN = ::core::option::Option<unsafe extern "system" fn(dwreserved: u32) -> u32>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-pub type PNS_OSVERSIONCHECK = ::core::option::Option<unsafe extern "system" fn(cimostype: u32, cimosproductsuite: u32, cimosversion: super::super::Foundation::PWSTR, cimosbuildnumber: super::super::Foundation::PWSTR, cimservicepackmajorversion: super::super::Foundation::PWSTR, cimservicepackminorversion: super::super::Foundation::PWSTR, uireserved: u32, dwreserved: u32) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+pub type PNS_OSVERSIONCHECK = ::core::option::Option<unsafe extern "system" fn(cimostype: u32, cimosproductsuite: u32, cimosversion: ::windows::core::PCWSTR, cimosbuildnumber: ::windows::core::PCWSTR, cimservicepackmajorversion: ::windows::core::PCWSTR, cimservicepackminorversion: ::windows::core::PCWSTR, uireserved: u32, dwreserved: u32) -> super::super::Foundation::BOOL>;
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn PreprocessCommand<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::HANDLE>>(hmodule: Param0, ppwcarguments: *mut super::super::Foundation::PWSTR, dwcurrentindex: u32, dwargcount: u32, ptttags: *mut TAG_TYPE, dwtagcount: u32, dwminargs: u32, dwmaxargs: u32, pdwtagtype: *mut u32) -> u32 {
+pub unsafe fn PreprocessCommand<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::HANDLE>>(hmodule: Param0, ppwcarguments: &mut [::windows::core::PWSTR], dwcurrentindex: u32, ptttags: &mut [TAG_TYPE], dwminargs: u32, dwmaxargs: u32, pdwtagtype: *mut u32) -> u32 {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn PreprocessCommand(hmodule: super::super::Foundation::HANDLE, ppwcarguments: *mut super::super::Foundation::PWSTR, dwcurrentindex: u32, dwargcount: u32, ptttags: *mut TAG_TYPE, dwtagcount: u32, dwminargs: u32, dwmaxargs: u32, pdwtagtype: *mut u32) -> u32;
+            fn PreprocessCommand(hmodule: super::super::Foundation::HANDLE, ppwcarguments: *mut ::windows::core::PWSTR, dwcurrentindex: u32, dwargcount: u32, ptttags: *mut TAG_TYPE, dwtagcount: u32, dwminargs: u32, dwmaxargs: u32, pdwtagtype: *mut u32) -> u32;
         }
-        ::core::mem::transmute(PreprocessCommand(hmodule.into_param().abi(), ::core::mem::transmute(ppwcarguments), ::core::mem::transmute(dwcurrentindex), ::core::mem::transmute(dwargcount), ::core::mem::transmute(ptttags), ::core::mem::transmute(dwtagcount), ::core::mem::transmute(dwminargs), ::core::mem::transmute(dwmaxargs), ::core::mem::transmute(pdwtagtype)))
+        ::core::mem::transmute(PreprocessCommand(hmodule.into_param().abi(), ::core::mem::transmute(::windows::core::as_mut_ptr_or_null(ppwcarguments)), ::core::mem::transmute(dwcurrentindex), ppwcarguments.len() as _, ::core::mem::transmute(::windows::core::as_mut_ptr_or_null(ptttags)), ptttags.len() as _, ::core::mem::transmute(dwminargs), ::core::mem::transmute(dwmaxargs), ::core::mem::transmute(pdwtagtype)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn PrintError<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::HANDLE>>(hmodule: Param0, dwerrid: u32) -> u32 {
@@ -570,22 +567,21 @@ pub unsafe fn PrintError<'a, Param0: ::windows::core::IntoParam<'a, super::super
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 #[inline]
-pub unsafe fn PrintMessage<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::PWSTR>>(pwszformat: Param0) -> u32 {
+pub unsafe fn PrintMessage<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::PCWSTR>>(pwszformat: Param0) -> u32 {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn PrintMessage(pwszformat: super::super::Foundation::PWSTR) -> u32;
+            fn PrintMessage(pwszformat: ::windows::core::PCWSTR) -> u32;
         }
         ::core::mem::transmute(PrintMessage(pwszformat.into_param().abi()))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn PrintMessageFromModule<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::HANDLE>>(hmodule: Param0, dwmsgid: u32) -> u32 {
@@ -600,7 +596,7 @@ pub unsafe fn PrintMessageFromModule<'a, Param0: ::windows::core::IntoParam<'a,
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn RegisterContext(pchildcontext: *const NS_CONTEXT_ATTRIBUTES) -> u32 {
@@ -615,7 +611,7 @@ pub unsafe fn RegisterContext(pchildcontext: *const NS_CONTEXT_ATTRIBUTES) -> u3
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 #[inline]
 pub unsafe fn RegisterHelper(pguidparentcontext: *const ::windows::core::GUID, pfnregistersubcontext: *const NS_HELPER_ATTRIBUTES) -> u32 {
     #[cfg(windows)]
@@ -630,10 +626,10 @@ pub unsafe fn RegisterHelper(pguidparentcontext: *const ::windows::core::GUID, p
     unimplemented!("Unsupported target OS");
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct TAG_TYPE {
-    pub pwszTag: super::super::Foundation::PWSTR,
+    pub pwszTag: ::windows::core::PCWSTR,
     pub dwRequired: u32,
     pub bPresent: super::super::Foundation::BOOL,
 }
@@ -670,39 +666,31 @@ impl ::core::default::Default for TAG_TYPE {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_NetworkManagement_NetShell', 'Win32_Foundation'*"]
-#[cfg(feature = "Win32_Foundation")]
+#[doc = "*Required features: `\"Win32_NetworkManagement_NetShell\"`*"]
 pub struct TOKEN_VALUE {
-    pub pwszToken: super::super::Foundation::PWSTR,
+    pub pwszToken: ::windows::core::PCWSTR,
     pub dwValue: u32,
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for TOKEN_VALUE {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for TOKEN_VALUE {
     fn clone(&self) -> Self {
         *self
     }
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::fmt::Debug for TOKEN_VALUE {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_struct("TOKEN_VALUE").field("pwszToken", &self.pwszToken).field("dwValue", &self.dwValue).finish()
     }
 }
-#[cfg(feature = "Win32_Foundation")]
 unsafe impl ::windows::core::Abi for TOKEN_VALUE {
     type Abi = Self;
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for TOKEN_VALUE {
     fn eq(&self, other: &Self) -> bool {
         unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<TOKEN_VALUE>()) == 0 }
     }
 }
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::Eq for TOKEN_VALUE {}
-#[cfg(feature = "Win32_Foundation")]
 impl ::core::default::Default for TOKEN_VALUE {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
