@@ -1,41 +1,18 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const DISPID_EVENT_ON_CONTEXT_DATA: u32 = 7u32;
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const DISPID_EVENT_ON_SEND_ERROR: u32 = 8u32;
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const DISPID_EVENT_ON_STATE_CHANGED: u32 = 5u32;
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const DISPID_EVENT_ON_TERMINATION: u32 = 6u32;
-#[doc = "*Required features: 'Win32_System_RemoteAssistance', 'Win32_System_Com'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`, `\"Win32_System_Com\"`*"]
 #[cfg(feature = "Win32_System_Com")]
 #[repr(transparent)]
 pub struct DRendezvousSessionEvents(::windows::core::IUnknown);
 #[cfg(feature = "Win32_System_Com")]
-impl DRendezvousSessionEvents {
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance', 'Win32_System_Com'*"]
-    #[cfg(feature = "Win32_System_Com")]
-    pub unsafe fn GetTypeInfoCount(&self) -> ::windows::core::Result<u32> {
-        let mut result__: u32 = ::core::mem::zeroed();
-        (::windows::core::Interface::vtable(self).base.GetTypeInfoCount)(::core::mem::transmute_copy(self), ::core::mem::transmute(&mut result__)).from_abi::<u32>(result__)
-    }
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance', 'Win32_System_Com'*"]
-    #[cfg(feature = "Win32_System_Com")]
-    pub unsafe fn GetTypeInfo(&self, itinfo: u32, lcid: u32) -> ::windows::core::Result<super::Com::ITypeInfo> {
-        let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
-        (::windows::core::Interface::vtable(self).base.GetTypeInfo)(::core::mem::transmute_copy(self), ::core::mem::transmute(itinfo), ::core::mem::transmute(lcid), ::core::mem::transmute(&mut result__)).from_abi::<super::Com::ITypeInfo>(result__)
-    }
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance', 'Win32_Foundation', 'Win32_System_Com'*"]
-    #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com"))]
-    pub unsafe fn GetIDsOfNames(&self, riid: *const ::windows::core::GUID, rgsznames: *const super::super::Foundation::PWSTR, cnames: u32, lcid: u32, rgdispid: *mut i32) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).base.GetIDsOfNames)(::core::mem::transmute_copy(self), ::core::mem::transmute(riid), ::core::mem::transmute(rgsznames), ::core::mem::transmute(cnames), ::core::mem::transmute(lcid), ::core::mem::transmute(rgdispid)).ok()
-    }
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance', 'Win32_Foundation', 'Win32_System_Com', 'Win32_System_Ole'*"]
-    #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
-    pub unsafe fn Invoke(&self, dispidmember: i32, riid: *const ::windows::core::GUID, lcid: u32, wflags: u16, pdispparams: *const super::Com::DISPPARAMS, pvarresult: *mut super::Com::VARIANT, pexcepinfo: *mut super::Com::EXCEPINFO, puargerr: *mut u32) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).base.Invoke)(::core::mem::transmute_copy(self), ::core::mem::transmute(dispidmember), ::core::mem::transmute(riid), ::core::mem::transmute(lcid), ::core::mem::transmute(wflags), ::core::mem::transmute(pdispparams), ::core::mem::transmute(pvarresult), ::core::mem::transmute(pexcepinfo), ::core::mem::transmute(puargerr)).ok()
-    }
-}
+impl DRendezvousSessionEvents {}
 #[cfg(feature = "Win32_System_Com")]
 impl ::core::convert::From<DRendezvousSessionEvents> for ::windows::core::IUnknown {
     fn from(value: DRendezvousSessionEvents) -> Self {
@@ -55,7 +32,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for DRendezvo
     }
 }
 #[cfg(feature = "Win32_System_Com")]
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &DRendezvousSessionEvents {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a DRendezvousSessionEvents {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -79,7 +56,7 @@ impl<'a> ::windows::core::IntoParam<'a, super::Com::IDispatch> for DRendezvousSe
     }
 }
 #[cfg(feature = "Win32_System_Com")]
-impl<'a> ::windows::core::IntoParam<'a, super::Com::IDispatch> for &DRendezvousSessionEvents {
+impl<'a> ::windows::core::IntoParam<'a, super::Com::IDispatch> for &'a DRendezvousSessionEvents {
     fn into_param(self) -> ::windows::core::Param<'a, super::Com::IDispatch> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -115,11 +92,11 @@ unsafe impl ::windows::core::Interface for DRendezvousSessionEvents {
 pub struct DRendezvousSessionEvents_Vtbl {
     pub base: super::Com::IDispatch_Vtbl,
 }
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 #[repr(transparent)]
 pub struct IRendezvousApplication(::windows::core::IUnknown);
 impl IRendezvousApplication {
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+    #[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
     pub unsafe fn SetRendezvousSession<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::IUnknown>>(&self, prendezvoussession: Param0) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).SetRendezvousSession)(::core::mem::transmute_copy(self), prendezvoussession.into_param().abi()).ok()
     }
@@ -139,7 +116,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IRendezvo
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IRendezvousApplication {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IRendezvousApplication {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -170,32 +147,32 @@ pub struct IRendezvousApplication_Vtbl {
     pub base: ::windows::core::IUnknownVtbl,
     pub SetRendezvousSession: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, prendezvoussession: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 #[repr(transparent)]
 pub struct IRendezvousSession(::windows::core::IUnknown);
 impl IRendezvousSession {
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+    #[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
     pub unsafe fn State(&self) -> ::windows::core::Result<RENDEZVOUS_SESSION_STATE> {
         let mut result__: RENDEZVOUS_SESSION_STATE = ::core::mem::zeroed();
         (::windows::core::Interface::vtable(self).State)(::core::mem::transmute_copy(self), ::core::mem::transmute(&mut result__)).from_abi::<RENDEZVOUS_SESSION_STATE>(result__)
     }
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance', 'Win32_Foundation'*"]
+    #[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`, `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
     pub unsafe fn RemoteUser(&self) -> ::windows::core::Result<super::super::Foundation::BSTR> {
         let mut result__: ::core::mem::ManuallyDrop<super::super::Foundation::BSTR> = ::core::mem::zeroed();
         (::windows::core::Interface::vtable(self).RemoteUser)(::core::mem::transmute_copy(self), ::core::mem::transmute(&mut result__)).from_abi::<super::super::Foundation::BSTR>(result__)
     }
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+    #[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
     pub unsafe fn Flags(&self) -> ::windows::core::Result<i32> {
         let mut result__: i32 = ::core::mem::zeroed();
         (::windows::core::Interface::vtable(self).Flags)(::core::mem::transmute_copy(self), ::core::mem::transmute(&mut result__)).from_abi::<i32>(result__)
     }
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance', 'Win32_Foundation'*"]
+    #[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`, `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
     pub unsafe fn SendContextData<'a, Param0: ::windows::core::IntoParam<'a, super::super::Foundation::BSTR>>(&self, bstrdata: Param0) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).SendContextData)(::core::mem::transmute_copy(self), bstrdata.into_param().abi()).ok()
     }
-    #[doc = "*Required features: 'Win32_System_RemoteAssistance', 'Win32_Foundation'*"]
+    #[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`, `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
     pub unsafe fn Terminate<'a, Param1: ::windows::core::IntoParam<'a, super::super::Foundation::BSTR>>(&self, hr: ::windows::core::HRESULT, bstrappdata: Param1) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).Terminate)(::core::mem::transmute_copy(self), ::core::mem::transmute(hr), bstrappdata.into_param().abi()).ok()
@@ -216,7 +193,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IRendezvo
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IRendezvousSession {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IRendezvousSession {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -260,21 +237,21 @@ pub struct IRendezvousSession_Vtbl {
     #[cfg(not(feature = "Win32_Foundation"))]
     Terminate: usize,
 }
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct RENDEZVOUS_SESSION_FLAGS(pub i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSF_NONE: RENDEZVOUS_SESSION_FLAGS = RENDEZVOUS_SESSION_FLAGS(0i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSF_INVITER: RENDEZVOUS_SESSION_FLAGS = RENDEZVOUS_SESSION_FLAGS(1i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSF_INVITEE: RENDEZVOUS_SESSION_FLAGS = RENDEZVOUS_SESSION_FLAGS(2i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSF_ORIGINAL_INVITER: RENDEZVOUS_SESSION_FLAGS = RENDEZVOUS_SESSION_FLAGS(4i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSF_REMOTE_LEGACYSESSION: RENDEZVOUS_SESSION_FLAGS = RENDEZVOUS_SESSION_FLAGS(8i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSF_REMOTE_WIN7SESSION: RENDEZVOUS_SESSION_FLAGS = RENDEZVOUS_SESSION_FLAGS(16i32);
 impl ::core::marker::Copy for RENDEZVOUS_SESSION_FLAGS {}
 impl ::core::clone::Clone for RENDEZVOUS_SESSION_FLAGS {
@@ -295,25 +272,25 @@ impl ::core::fmt::Debug for RENDEZVOUS_SESSION_FLAGS {
         f.debug_tuple("RENDEZVOUS_SESSION_FLAGS").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct RENDEZVOUS_SESSION_STATE(pub i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSS_UNKNOWN: RENDEZVOUS_SESSION_STATE = RENDEZVOUS_SESSION_STATE(0i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSS_READY: RENDEZVOUS_SESSION_STATE = RENDEZVOUS_SESSION_STATE(1i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSS_INVITATION: RENDEZVOUS_SESSION_STATE = RENDEZVOUS_SESSION_STATE(2i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSS_ACCEPTED: RENDEZVOUS_SESSION_STATE = RENDEZVOUS_SESSION_STATE(3i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSS_CONNECTED: RENDEZVOUS_SESSION_STATE = RENDEZVOUS_SESSION_STATE(4i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSS_CANCELLED: RENDEZVOUS_SESSION_STATE = RENDEZVOUS_SESSION_STATE(5i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSS_DECLINED: RENDEZVOUS_SESSION_STATE = RENDEZVOUS_SESSION_STATE(6i32);
-#[doc = "*Required features: 'Win32_System_RemoteAssistance'*"]
+#[doc = "*Required features: `\"Win32_System_RemoteAssistance\"`*"]
 pub const RSS_TERMINATED: RENDEZVOUS_SESSION_STATE = RENDEZVOUS_SESSION_STATE(7i32);
 impl ::core::marker::Copy for RENDEZVOUS_SESSION_STATE {}
 impl ::core::clone::Clone for RENDEZVOUS_SESSION_STATE {
